<?php
/**
* Web based SQLite management
* @package SQLiteManager
* @version $Id: french.inc.php,v 1.56 2006/04/14 15:16:52 freddy78 Exp $ $Revision: 1.56 $
*/
$charset = 'iso-8859-1';
$langSuffix = 'fr';
/**
* Fichier d'internationnalisation
*/
$itemTranslated = array(	"Table"		=> "Table",
							"View"		=> "Vue",
							"Trigger"	=> "Déclencheur",
							"Function"	=> "Fonction");

$langueTranslated = array(	1=>"Français", 2=>"Anglais", 3=>"Polonais",
							4=>"Allemand", 5=>"Japonais", 6=>"Italien",
							7=>"Croate" , 8=>"Bresilien (portugais)", 9=>"Hollandais",
							10=>"Espagnol" ,11=>"Danois", 12=>"Chinois traditionnel", 
							13=>"Chinois simplifié");

$themeTranslated = array("default"=>"Standard", "green"=>"Vert", "PMA"=>"PMA", "jall"=>"JALL");

$TEXT[1]	=	"Accueil";
$TEXT[2]	=	"Bienvenue dans <a href=\"http://www.sqlitemanager.org\" target=\"_blank\">SQLiteManager</a> version";
$TEXT[3]	=	"SQLite version";
$TEXT[4]	=	"Documentation SQLite";
$TEXT[5]	=	"Langage SQL";
$TEXT[6]	=	"L'extension SQLite ne peut être chargée.";
$TEXT[7]	=	"Impossible d'ouvrir la base 'SQLite' de configuration.<br>Message d'erreur";
$TEXT[8]	=	"La base de configuration n'a pas les droits en ecriture!";
$TEXT[9]	=	"Erreur";
$TEXT[10]	=	"Fonction";
$TEXT[11]	=	"Agrégation";
$TEXT[12]	=	"Fonction final";
$TEXT[13]	=	"Nb Arguments";
$TEXT[14]	=	"Modifier";
$TEXT[15]	=	"Supprimer";
$TEXT[16]	=	"Propriétés de la nouvelle fonction";
$TEXT[17]	=	"Propriétés de la fonction";
$TEXT[18]	=	"Erreur : Tous les champs doivent être saisis.";
$TEXT[19]	=	"Nom";
$TEXT[20]	=	"Type";
$TEXT[21]	=	"Propriétés Step";
$TEXT[22]	=	"Propriétés Final";
$TEXT[23]	=	"Nb arguments";
$TEXT[24]	=	"Attribuer cette fonction à toutes les bases.";
$TEXT[25]	=	"Propriétés de la nouvelle table";
$TEXT[26]	=	"Propriétés de la table";
$TEXT[27]	=	"Champ";
$TEXT[28]	=	"Type";
$TEXT[29]	=	"Longueur";
$TEXT[30]	=	"Null";
$TEXT[31]	=	"Défaut";
$TEXT[32]	=	"Primaire";
$TEXT[33]	=	"Action";
$TEXT[34]	=	"Tout cocher";
$TEXT[35]	=	"Tout décocher";
$TEXT[36]	=	"Pour la sélection";
$TEXT[37]	=	"Etes vous certain de vouloir supprimer ce/ces champ(s)?";
$TEXT[38]	=	"Gestion des index";
$TEXT[39]	=	"Etes vous certain de vouloir supprimer le champ";
$TEXT[40]	=	"Oui";
$TEXT[41]	=	"Non";
$TEXT[42]	=	"Primaire";
$TEXT[43]	=	"Ajouter";
$TEXT[44]	=	"champ(s)";
$TEXT[45]	=	"En fin de table";
$TEXT[46]	=	"En début de table";
$TEXT[47]	=	"Après";
$TEXT[48]	=	"Insertion d'un nouvel enregistrement";
$TEXT[49]	=	"Modification d'un enregistrement";
$TEXT[50]	=	"Valeur";
$TEXT[51]	=	"Enregistrer";
$TEXT[52]	=	"Insérer des données à partir d'un fichier.";
$TEXT[53]	=	"Déclencheur";
$TEXT[54]	=	"Propriétés du nouveau déclencheur";
$TEXT[55]	=	"Propriétés du déclencheur";
$TEXT[56]	=	"Moment";
$TEXT[57]	=	"Event";
$TEXT[58]	=	"On";
$TEXT[59]	=	"Condition";
$TEXT[60]	=	"Step";
$TEXT[61]	=	"Propriétés";
$TEXT[62]	=	"Propriétés de la nouvelle vue";
$TEXT[63]	=	"Propriétés de la vue";
$TEXT[64]	=	"Aucune requête à exécuter!";
$TEXT[65]	=	"Mauvaise ressource de connexion!";
$TEXT[66]	=	"Exécuter une ou des <b>requête(s)";
$TEXT[67]	=	"<i>Ou</i> à partir d'un fichier SQL";
$TEXT[68]	=	"Format des requêtes : Standard (SQLite)";
$TEXT[69]	=	"Exécuter";
$TEXT[70]	=	"requêtes ont été exécutées.";
$TEXT[71]	=	"lignes ont été modifiées.";
$TEXT[72]	=	"Structure";
$TEXT[73]	=	"Afficher";
$TEXT[74]	=	"SQL";
$TEXT[75]	=	"Insérer";
$TEXT[76]	=	"Export";
$TEXT[77]	=	"Vider";
$TEXT[78]	=	"Voulez-vous vraiment supprimer cette fonction?";
$TEXT[79]	=	"Voulez-vous vraiment vider le contenu de cette table?";
$TEXT[80]	=	"Voulez-vous vraiment supprimer cette table?";
$TEXT[81]	=	"Ajouter";
$TEXT[82]	=	"Voulez-vous vraiment supprimer cette vue?";
$TEXT[83]	=	"Voulez-vous vraiment supprimer ce déclencheur?";
$TEXT[84]	=	"Options";
$TEXT[85]	=	"Etes vous certain de vouloir supprimer cette base? Cette suppression n'est qu'une désinscription, la base n'est pas détruite.";
$TEXT[86]	=	"Supprimer";
$TEXT[87]	=	"Ajouter une nouvelle Vue";
$TEXT[88]	=	"Ajouter un nouveau Déclencheur";
$TEXT[89]	=	"Ajouter une nouvelle Fonction";
$TEXT[90]	=	"Requête SQL";
$TEXT[91]	=	"Nom de la clé";
$TEXT[92]	=	"Etes vous certain de vouloir supprimer l'index";
$TEXT[93]	=	"Ajouter un index sur";
$TEXT[94]	=	"colonne(s)";
$TEXT[95]	=	"Ignorer";
$TEXT[96]	=	"Ajouter à la clef";
$TEXT[97]	=	"Créer une vue nommée";
$TEXT[98]	=	"à partir de cette requête.";
$TEXT[99]	=	"Erreur ligne(s)";
$TEXT[100]	=	"Il y a certainement un problème de droits en écriture sur la base de configuration";
$TEXT[101]	=	"Impossible de créer ou d'accéder à cette base";
$TEXT[102]	=	"Tous les champs doivent être saisi!";
$TEXT[103]	=	"Créer ou ajouter une nouvelle base";
$TEXT[104]	=	"Chemin";
$TEXT[105]	=	"Le tableau de données n'a pas un nombre d'éléments constant";
$TEXT[106]	=	"Le paramètre passé au constructeur de la classe 'Grid' doit être un tableau";
$TEXT[107]	=	"Le tableau pour l'alignement des colonnes ne comporte pas le bon nombre d'éléments.";
$TEXT[108]	=	"L'alignement d'une cellule doit être : 'left', 'right' ou 'center'";
$TEXT[109]	=	"Le paramètre permettant de fixer l'alignement des colonnes doit être un tableau";
$TEXT[110]	=	"Le paramètre permettant de fixer le format des colonnes doit être un tableau";
$TEXT[111]	=	"Le tableau pour le tri des colonnes ne comporte pas le bon nombre d'éléments.";
$TEXT[112]	=	"Le paramètre de tri doit être soit 0=pas de tri, soit 1=tri.";
$TEXT[113]	=	"Le paramètre permettant de fixer les colonnes à trier doit être un tableau";
$TEXT[114]	=	"La chaine de format de la colonne calculée est vide.";
$TEXT[115]	=	"Le titre est obligatoire pour une colonne calculée.";
$TEXT[116]	=	"Le paramètre du constructeur de la classe 'ArrayToGrid' doit être un tableau";
$TEXT[117]	=	"Impossible de compter le nombre d'enregistrement";
$TEXT[118]	=	"Nb Enregistrement";
$TEXT[119] =	"Insérer";
$TEXT[120]	=	"Etes vous certain de vouloir supprimer";
$TEXT[121]	=	"le";
$TEXT[122]	=	"la";
$TEXT[123]	=	"Etes vous certain de vouloir vider la table";
$TEXT[124]	=	"Structure seule";
$TEXT[125]	=	"Structure et données";
$TEXT[126]	=	"Données seules";
$TEXT[127]	=	"Insertion complète";
$TEXT[128]	=	"Transmettre";
$TEXT[129]	=	"Serveur";
$TEXT[130]	=	"Généré le";
$TEXT[131]	=	"Base de données";
$TEXT[132]	=	"Structure de la table";
$TEXT[133]	=	"Contenu de la table";
$TEXT[134]	=	"Structure de la vue";
$TEXT[135]	=	"Propriété de la fonction";
$TEXT[136]	=	"Enregistrements";
$TEXT[137]	=	"Fichier";
$TEXT[138]	=	"Remplacer le contenu";
$TEXT[139]	=	"Séparateur";
$TEXT[140]	=	"Insertion de données à partir d'un fichier texte formaté";
$TEXT[141]	=	"Langue";
$TEXT[142]	=	"Thème";
$TEXT[143]	=	"Télécharger la base";
$TEXT[144]	=	"Le répertoire de téléchargement n'est pas accessible.<br>(Modifier la constante 'DEFAULT_DB_PATH' dans le fichier 'include/user_defined.inc.php')";
$TEXT[145]	=	"Expliquer SQL";
$TEXT[146]	=	"Gestion des bases de données attachées";
$TEXT[147]	=	"Vous n'êtes pas autorisé à accéder à cet espace. Veuillez saisir un identifiant et un mot de passe valide.";
$TEXT[148]	=	"Cet identifiant n'est pas valide.";
$TEXT[149]	=	"Ce mot de passe ne correspond pas à cet identifiant.";
$TEXT[150]	=	"PHP version";
$TEXT[151]	= 	"Après enregistrement";
$TEXT[152]	= 	"Retour à la page précédente";
$TEXT[153]	= 	"Insertion d'un nouvel élément";
$TEXT[154]	= 	"La base de configuration est en lecture seule.<br>Certaines fonctionnalités de SQLiteManager peuvent ne pas fonctionner correctement.";
$TEXT[155]	= 	"La base de donnée est en lecture seule.";
$TEXT[156]	= 	"Privilèges";
$TEXT[157]	= 	"Changement du mot de passe";
$TEXT[158]	= 	"Déconnexion";
$TEXT[159]	= 	"Ajouter un utilisateur";
$TEXT[160]	= 	"Ajouter un groupe";
$TEXT[161]	= 	"Liste des utilisateurs";
$TEXT[162]	= 	"Liste des groupes";
$TEXT[163]	= 	"Nom";
$TEXT[164]	= 	"Login";
$TEXT[165]	= 	"Groupe";
$TEXT[166] = 	"execSQL";
$TEXT[167]	= 	"data";
$TEXT[168]	= 	"export";
$TEXT[169]	= 	"empty";
$TEXT[170]	= 	"del";
$TEXT[171]	= 	"Ancien mot de passe incorrect.";
$TEXT[172]	= 	"Mot de passe et confirmation sont différents.";
$TEXT[173]	= 	"Mot de passe modifié";
$TEXT[174]	= 	"Cliquez içi pour vous reconnecter";
$TEXT[175]	= 	"Ancien :";
$TEXT[176]	= 	"Nouveau :";
$TEXT[177]	= 	"Confirmer :";
$TEXT[178]	= 	"Informations";
$TEXT[179]	= 	"Emplacement :";
$TEXT[180]	= 	"Taille :";
$TEXT[181]	= 	"Droits :";
$TEXT[182]	= 	"Dernière modification :";
$TEXT[183]	= 	"Contrôle d'intégrité";
$TEXT[184]	= 	"Vacuum";
$TEXT[185]	= 	"Synchronisation par défaut :";
$TEXT[186]	= 	"Taille du cache :";
$TEXT[187]	= 	"OFF ";
$TEXT[188]	= 	"NORMAL ";
$TEXT[189]	= 	"FULL ";
$TEXT[190]	= 	"Gestion du contrôle d'accès";
$TEXT[191]	= 	"Oui";
$TEXT[192]	= 	"Non";
$TEXT[193]	= 	"Stockage temporaire par défaut :";
$TEXT[194]	= 	"DEFAULT";
$TEXT[195]	= 	"MEMORY";
$TEXT[196]	= 	"FILE";
$TEXT[197]	= 	"Unique";
$TEXT[198]	= 	"Index";
$TEXT[199]	= 	"Données";
$TEXT[200]	= 	"Appliquer";
$TEXT[201]	=	"Sélection";
$TEXT[202]	=	"Opérateur";
$TEXT[203]	=	"Condition(s) supplémentaire(s) :";
$TEXT[204]	=	"AND";
$TEXT[205]	=	"OR";
$TEXT[206]	=	"Select";
$TEXT[207]	=	"Rechercher";
$TEXT[208]	=	"Renommer";
$TEXT[209]	=	"Déplacer";
$TEXT[210]	=	"Dupliquer";
$TEXT[211]	=	"Plugins";
$TEXT[212]	=	"Maintenance";
$TEXT[213]	=	"Requête exécutée en";
$TEXT[214]	=	"msec.";
$TEXT[215]	=	"Changer le nom de la table pour :";
$TEXT[216]	=	"Déplacer la table vers (base.table) :";
$TEXT[217]	=	"Copier la table vers (base.table) :";
$TEXT[218]	=	"Ajouter DROP TABLE";
$TEXT[219]  =   "Insérer en tant que nouvel enregistrement";
$TEXT[220]  =   "Enregistrer";
$TEXT[221]  =   "Methode d'enregistrement";
$TEXT[222]  =   "Opération";
$TEXT[223]  =   "Actualiser";
$TEXT[224]  =   "Astuce : Vous pouvez utiliser les fonctions interne à PHP dans vos requêtes !";
$TEXT[225]  =   "Texte tronqué";
$TEXT[226]  =   "Texte plein";
$TEXT[227]  =   "-- select --";
$TEXT[228]  =   "(s)";
$TEXT[229]  =   "Version";
$TEXT[230]  =   "(nouvelle base de données)";
$TEXT[231]  =   "Site officiel de SQLiteManager";
$TEXT[232]  =   "La base de données est inaccessible";
$TEXT[233]  =   "Définition des Déclencheurs";
?>
