<?php
/**
* Web based SQLite management
* @package SQLiteManager
* @version $Id: italian.inc.php,v 1.35 2006/04/14 15:16:52 freddy78 Exp $ $Revision: 1.35 $
*/
/*
  Paolo Saudin (http//:www.dreamof.biz)
*/
$charset = 'iso-8859-1';
$langSuffix = 'it';
/**
* File d'internazionalizzazione
*/
$itemTranslated = array(  "Table"   => "Tabella",
              "View"    => "Vista",
              "Trigger" => "Trigger",
              "Function"  => "Funzione");

$langueTranslated = array(	1=>"Francese", 2=>"Inglese", 3=>"Polacco", 
							4=>"Tedesco", 5=>"Giapponese", 6=>"Italiano", 
							7=>"Croato", 8=>"Brasiliano portoghese", 9=>"Olandese", 
							10=>"Spagnolo", 11=>"Danish", 12=>"Chinese traditional", 
              				13=>"Chinese simplified");

$themeTranslated = array("default"=>"Default",  "PMA"=>"PMA", "jall"=>"JALL", "green"=>"Green");


$TEXT[1]  = "Home";
$TEXT[2]  = "Benvenuto in <a href=\"http://www.sqlitemanager.org\" target=\"_blank\">SQLiteManager</a> versione";
$TEXT[3]  = "Versione SQLite";
$TEXT[4]  = "Documentazione SQLite";
$TEXT[5]  = "Linguaggio SQL";
$TEXT[6]  = "L'estensione di SQLite non può essere caricata.";
$TEXT[7]  = "Impossibile aprire il database di configurazione 'SQLite'.<br>Messaggio di errore";
$TEXT[8]  = "Il database di configurazione non è accessibile in scrittura.";
$TEXT[9]  = "Errore";
$TEXT[10] = "Funzione";
$TEXT[11] = "Aggragato";
$TEXT[12] = "Funzione finale";
$TEXT[13] = "N. Argomenti";
$TEXT[14] = "Modifica";
$TEXT[15] = "Elimina";
$TEXT[16] = "Proprietà della nuova funzione";
$TEXT[17] = "Proprietà della funzione";
$TEXT[18] = "Errore : Tutti i campi devono essere compilati.";
$TEXT[19] = "Nome";
$TEXT[20] = "Tipo";
$TEXT[21] = "Proprietà Step";
$TEXT[22] = "Proprietà Final";
$TEXT[23] = "N. Argomenti";
$TEXT[24] = "Attribuire questa funzione a tutti i database.";
$TEXT[25] = "Proprietà della nuova tabella";
$TEXT[26] = "Proprietà della tabella";
$TEXT[27] = "Campo";
$TEXT[28] = "Tipo";
$TEXT[29] = "Lunghezza";
$TEXT[30] = "Nullo";
$TEXT[31] = "Default";
$TEXT[32] = "Primario";
$TEXT[33] = "Azione";
$TEXT[34] = "Seleziona tutti";
$TEXT[35] = "Deseleziona tutti";
$TEXT[36] = "Per la selezione";
$TEXT[37] = "Sei sicuro di voler eliminare questo/questi campi?";
$TEXT[38] = "Gestione degli indici";
$TEXT[39] = "Sei sicuro di voler eliminare questo campo";
$TEXT[40] = "Sì";
$TEXT[41] = "No";
$TEXT[42] = "Primario";
$TEXT[43] = "Aggiungi";
$TEXT[44] = "Campo(i)";
$TEXT[45] = "Alla fine della tabella";
$TEXT[46] = "All' inizio della tabella";
$TEXT[47] = "Dopo";
$TEXT[48] = "Inserire un nuovo record";
$TEXT[49] = "Modifica di un record";
$TEXT[50] = "Valore";
$TEXT[51] = "Salva";
$TEXT[52] = "Inserisci dati da un file";
$TEXT[53] = "Trigger";
$TEXT[54] = "Proprietà nuovo trigger";
$TEXT[55] = "Proprietà trigger";
$TEXT[56] = "Tempo";
$TEXT[57] = "Evento";
$TEXT[58] = "On";
$TEXT[59] = "Condizione";
$TEXT[60] = "Step";
$TEXT[61] = "Proprietà";
$TEXT[62] = "Proprietà della nuova vista";
$TEXT[63] = "Proprietà vista";
$TEXT[64] = "Nessuna richiesta eseguita!";
$TEXT[65] = "Risorsa di connessione non valida!";
$TEXT[66] = "Esegui una o più <b>richieste";
$TEXT[67] = "<i>O</i> da un file sql";
$TEXT[68] = "Formato richieste : Standard (sqlite)";
$TEXT[69] = "Esegui";
$TEXT[70] = "richiesta eseguita.";
$TEXT[71] = "linee sono state modificate.";
$TEXT[72] = "Struttura";
$TEXT[73] = "Visualizza";
$TEXT[74] = "SQL";
$TEXT[75] = "Inserisci";
$TEXT[76] = "Esporta";
$TEXT[77] = "Cancella contenuto";
$TEXT[78] = "Vuoi veramente eliminare questa funzione?";
$TEXT[79] = "Vuoi veramente eliminare il contenuto di questa tabella?";
$TEXT[80] = "Vuoi veramente eliminare questa tabella?";
$TEXT[81] = "Aggiungi";
$TEXT[82] = "Vuoi veramente eliminare questa vista?";
$TEXT[83] = "Vuoi veramente eliminare questo trigger?";
$TEXT[84] = "Opzioni";
$TEXT[85] = "Sei sicuro di voler eliminare questo database? Questo eliminerà solo una voce di registrazione, il database non verrà eliminato.";
$TEXT[86] = "Elimina";
$TEXT[87] = "Aggiungi una nuova vista";
$TEXT[88] = "Aggiungi un nuovo trigger";
$TEXT[89] = "Aggiungi una nuova funzione";
$TEXT[90] = "Richiesta sql";
$TEXT[91] = "Nome della chiave";
$TEXT[92] = "Vuoi veramente eliminare questo indice?";
$TEXT[93] = "Aggiungi un indice a";
$TEXT[94] = "colonna(e)";
$TEXT[95] = "Ignora";
$TEXT[96] = "Aggiungi alla chiave";
$TEXT[97] = "Crea una vista con nome";
$TEXT[98] = "a partire da questa richiesta";
$TEXT[99] = "Errore linea(e)";
$TEXT[100] = "Esiste sicuramente un problema di diritti di scrittura sul database di configurazione";
$TEXT[101] = "Impossibile creare o leggere questo database";
$TEXT[102] = "Tutti i campi devono essere compilati!";
$TEXT[103] = "Aggiungi un nuovo database";
$TEXT[104] = "Percorso";
$TEXT[105] = "L'array contenente i dati non ha un numero costante di elementi";
$TEXT[106] = "Il parametro del costruttore della classe 'Grid' deve essere un array";
$TEXT[107] = "L'array per l'allineamento delle colonne ha un numero errarto di elementi.";
$TEXT[108] = "L'allineamento delle celle deve essere : 'left', 'right' o 'center'";
$TEXT[109] = "Il parametro per l'allineamento delle colonne deve essere un array";
$TEXT[110] = "Il parametro per il formato delle colonne deve essere un array";
$TEXT[111] = "L'array per l'ordinamento delle colonne ha un numero errarto di elementi.";
$TEXT[112] = "I parametri per l'ordinamento devono essere 0=nessun ordine, o 1=ordinato.";
$TEXT[113] = "Il parametro per l'ordinamento delle colonne deve essere un array";
$TEXT[114] = "La stringa del formato della colonna calcolata è vuota.";
$TEXT[115] = "Il titolo è obbligatorio per una colonna calcolata.";
$TEXT[116] = "Il parametro per il costruttore della classe 'ArrayToGrid' deve essere un'array.";
$TEXT[117] = "Impossibile contare il numero dei record";
$TEXT[118] = "N. record";
$TEXT[119] = "Inserisci";
$TEXT[120] = "Sei sicuro di voler cancellare";
$TEXT[121] = "il";
$TEXT[122] = "la";
$TEXT[123] = "Sei sicuro di voler eliminare il contenuto di questa tabella";
$TEXT[124] = "Solo struttura";
$TEXT[125] = "Struttura e dati";
$TEXT[126] = "Solo dati";
$TEXT[127] = "Inserimenti completi";
$TEXT[128] = "Invia";
$TEXT[129] = "Host";
$TEXT[130] = "Creato il";
$TEXT[131] = "Database";
$TEXT[132] = "Struttura della tabella";
$TEXT[133] = "Contenuto della tabella";
$TEXT[134] = "Struttura della vista";
$TEXT[135] = "Proprietà della funzione utente";
$TEXT[136] = "Records";
$TEXT[137] = "File";
$TEXT[138] = "Sostituire il contenuto";
$TEXT[139] = "Separatore";
$TEXT[140] = "Inserimento dati da un file preformattato";
$TEXT[141] = "Lingua";
$TEXT[142] = "Tema";
$TEXT[143] = "Trasferisci database";
$TEXT[144] = "Directory di trasferimento non accessibile.<br>(Modificare la costante 'DEFAULT_DB_PATH' nel file 'include/user_defined.inc.php')";
$TEXT[145] = "Spiegazione query SQL";
$TEXT[146] = "Gestione di database allegati";
$TEXT[147] = "Accesso non consentito. Devi inserire nome utente e password validi.";
$TEXT[148] = "Questo nome utente non è valido.";
$TEXT[149] = "La password non corrisponde al nome utente.";
$TEXT[150] = "Versione PHP";
$TEXT[151] = "Dopo il salvataggio";
$TEXT[152] = "Ritorna alla pagina precedente";
$TEXT[153] = "Inserisci un'altra riga";
$TEXT[154] = "La configurazione del database è di sola lettura.<br>Alcune operazioni di SQLiteManager potrebbero non funzionare correttamente.";
$TEXT[155] = "Questo database è di sola lettura.";
$TEXT[156] = "Privilegi";
$TEXT[157] = "Cambia password";
$TEXT[158] = "Esci";
$TEXT[159] = "Aggiungi utente";
$TEXT[160] = "Aggiungi gruppo";
$TEXT[161] = "Elenco utenti";
$TEXT[162] = "Elenco gruppi";
$TEXT[163] = "Nome";
$TEXT[164] = "Login";
$TEXT[165] = "Gruppo";
$TEXT[166] = "execSQL";
$TEXT[167] = "data";
$TEXT[168] = "esporta";
$TEXT[169] = "svuota";
$TEXT[170] = "cancella";
$TEXT[171] = "La vecchia password è sbagliata.";
$TEXT[172] = "La password e la sua conferma sono diverse.";
$TEXT[173] = "La password è stata cambiata";
$TEXT[174] = "Clicca qui per rieseguire il login";
$TEXT[175] = "Vecchia :";
$TEXT[176] = "Nuova :";
$TEXT[177] = "Conferma :";
$TEXT[178] = "Informazioni";
$TEXT[179] = "Percorso :";
$TEXT[180] = "Dimensioni :";
$TEXT[181] = "Permessi :";
$TEXT[182] = "Ultima modifica :";
$TEXT[183] = "Controllo Integrità";
$TEXT[184] = "Vacuum (pulizia)";
$TEXT[185] = "Sincronizzazione predefinita :";
$TEXT[186] = "Dimensioni cache predefinite :";
$TEXT[187] = "OFF (disattiva)";
$TEXT[188] = "NORMAL (normale)";
$TEXT[189] = "FULL (completa)";
$TEXT[190] = "Gestione controllo accesso"; 
$TEXT[191] = "Sì"; 
$TEXT[192] = "No"; 
$TEXT[193] = "Memorizzazione temporanea predefinita"; 
$TEXT[194] = "DEFAULT (predefinita)"; 
$TEXT[195] = "MEMORIA"; 
$TEXT[196] = "FILE (su disco)"; 
$TEXT[197] = "Unica"; 
$TEXT[198] = "Indice"; 
$TEXT[199] = "Dati";
$TEXT[200] = "Applica";
$TEXT[201] = "Selezione";
$TEXT[202] = "Operatore";
$TEXT[203] = "condizione aggiuntiva :";
$TEXT[204] = "AND (e)";
$TEXT[205] = "OR (o)";
$TEXT[206] = "Seleziona";
$TEXT[207] = "Cerca";
$TEXT[208] = "Rinomina";
$TEXT[209] = "Muovi";
$TEXT[210] = "Copia";
$TEXT[211] = "Plugin";
$TEXT[212] = "Manutenzione";
$TEXT[213] = "Durata query :";
$TEXT[214] = "ms";
$TEXT[215] = "Rinomina tabella in :";
$TEXT[216] = "Muovi tabella in (database.tabella) :";
$TEXT[217] = "Copia tabella in (database.tabella) :";
$TEXT[218] = "Aggiungi DROP TABLE";
$TEXT[219] = "Save as New Row";
$TEXT[220] = "Save";
$TEXT[221] = "Save Type";
$TEXT[222]  =   "Operation";
$TEXT[223]  =   "Update";
$TEXT[224]  =   "Tip : You can use internal PHP functions in your queries !";
$TEXT[225]  =   "Truncated text";
$TEXT[226]  =   "Full text";
$TEXT[227]  =   "-- select --";
$TEXT[228]  =   "(s)";
$TEXT[229]  =   "Version";
$TEXT[230]  =   "(new database)";
$TEXT[231]  =   "Official SQliteManager Homepage";
$TEXT[232]  =   "The database can't be attain";
$TEXT[233]  =   "Trigger structure";
?>