	a.base		{ color: teal; font-weight: bold; font-size: 12px; text-decoration: none }
	a.base:hover	{ color: #0E23C4; font-weight: bold; font-size: 12px; text-decoration: none }
	a.dbsel 		{ color: lavender; font-weight: bold; font-size: 12px; text-decoration: none }
	a.dbsel:hover 		{ color: white; font-weight: bold; font-size: 12px; text-decoration: none }
	a.item		{ font-family: Arial, Verdana; color: black; font-size: 12px; text-decoration: none}
	a.item:hover		{ font-family: Arial, Verdana; color: black; font-size: 12px; text-decoration: underline}
	body 			{ font-family: Arial, Verdana; background-color: #bbb }
	.database 	{ font-family: Arial, Verdana; background-color: green; text-indent: 5px }
	.item		  	{ font-family: Arial, Verdana; font-size: 10px; text-align: left; text-indent: 1em; vertical-align: middle }
