<?php
/**
* Web based SQLite management
* @package SQLiteManager
* @version $Id: danish.inc.php,v 1.9 2006/04/14 15:16:52 freddy78 Exp $ $Revision: 1.9 $
*/
$charset = 'iso-8859-1';
$langSuffix = 'en';
/**
* Fichier d'internationnalisation
*/
$itemTranslated = array(	"Table"		=> "Tabel", 
							"View"		=> "View",
							"Trigger"	=> "Trigger",
							"Function"	=> "Funktion");

$langueTranslated = array(	1=>"Fransk", 2=>"Engelsk", 3=>"Polsk", 
							4=>"Tysk", 5=>"Japansk", 6=>"Italiensk", 
							7=>"Kroatisk", 8=>"Brasiliansk portugesisk", 9=>"Hollandsk", 
							10=>"Spansk", 11=>"Dansk", 12=>"Chinese traditional", 
              				13=>"Chinese simplified");

$themeTranslated = array("default"=>"Standard",  "PMA"=>"PMA", "jall"=>"JALL","green"=>"Grøn");

$TEXT[1]	=	"Udgangspunkt";
$TEXT[2]	=	"Velkommen til <a href=\"http://www.sqlitemanager.org\" target=\"_blank\">SQLiteManager</a> version";
$TEXT[3]	=	"SQLite version";
$TEXT[4]	=	"SQLite dokumentation";
$TEXT[5]	=	"SQL Definition";
$TEXT[6]	=	"SQLite udvidelse kan ikke indlæses.";
$TEXT[7]	=	"'SQLite' konfigurationsdatabase kan ikke åbnes.<br>Fejlmelding";
$TEXT[8]	=	"Konfigurationsdatabase mangler skriverettigheder!";
$TEXT[9]	=	"Fejl";
$TEXT[10]	=	"Funktion";
$TEXT[11]	=	"Sammenlæg (Aggregate)";
$TEXT[12]	=	"Final function";
$TEXT[13]	=	"Antal Argumenter";
$TEXT[14]	=	"Modificer";
$TEXT[15]	=	"Slet";
$TEXT[16]	=	"Ny funktions egenskaber";
$TEXT[17]	=	"Funktion egenskaber";
$TEXT[18]	=	"Fejl : Alle felterne skal være udfyldt.";
$TEXT[19]	=	"Navn";
$TEXT[20]	=	"Type";
$TEXT[21]	=	"Step egenskaber";
$TEXT[22]	=	"Final egenskaber";
$TEXT[23]	=	"Antal argumenter";
$TEXT[24]	=	"Tillæg alle databaser denne funktion.";
$TEXT[25]	=	"Ny tabels egenskaber";
$TEXT[26]	=	"Tabel egenskaber";
$TEXT[27]	=	"Felt";
$TEXT[28]	=	"Type";
$TEXT[29]	=	"Længde";
$TEXT[30]	=	"Null";
$TEXT[31]	=	"Default";
$TEXT[32]	=	"Primær";
$TEXT[33]	=	"Bearbejd";
$TEXT[34]	=	"Marker alle";
$TEXT[35]	=	"Fjern alle markeringer";
$TEXT[36]	=	"For udvalget";
$TEXT[37]	=	"Er du sikker på at du vil slette dette/disse felter?";
$TEXT[38]	=	"Administration af index(er)";
$TEXT[39]	=	"Er du sikker på at du vil slette dette felt";
$TEXT[40]	=	"Ja";
$TEXT[41]	=	"Nej";
$TEXT[42]	=	"Primær";
$TEXT[43]	=	"Tilføj";
$TEXT[44]	=	"Felt(er)";
$TEXT[45]	=	"Ved tabellens slutning";
$TEXT[46]	=	"Ved tabellens begyndelse";
$TEXT[47]	=	"Efter";
$TEXT[48]	=	"Indsæt ny record";
$TEXT[49]	=	"Modificer record";
$TEXT[50]	=	"Værdi";
$TEXT[51]	=	"Gem";
$TEXT[52]	=	"Indsæt data fra en fil.";
$TEXT[53]	=	"Trigger";
$TEXT[54]	=	"Ny trigger egenskaber";
$TEXT[55]	=	"Trigger egenskaber";
$TEXT[56]	=	"Moment";
$TEXT[57]	=	"Event";
$TEXT[58]	=	"On";
$TEXT[59]	=	"Condition";
$TEXT[60]	=	"Step";
$TEXT[61]	=	"Egenskaber";
$TEXT[62]	=	"Nyt View egenskaber";
$TEXT[63]	=	"View egenskaber";
$TEXT[64]	=	"Der blev ikke udført nogen forespørgsel!";
$TEXT[65]	=	"Bas resource connection!";
$TEXT[66]	=	"Udfør en eller flere <b>forespørgs(el/ler)";
$TEXT[67]	=	"<i>Eller</i> fra en sql fil";
$TEXT[68]	=	"Forespørgselsformat : Standard (sqlite)";
$TEXT[69]	=	"Udfør";
$TEXT[70]	=	"forespørgsel er udført.";
$TEXT[71]	=	"Linie er ændret.";
$TEXT[72]	=	"Struktur";
$TEXT[73]	=	"Vis";
$TEXT[74]	=	"SQL";
$TEXT[75]	=	"Indsæt";
$TEXT[76]	=	"Eksporter";
$TEXT[77]	=	"Tøm";
$TEXT[78]	=	"Vil du virkelig eliminere denne funktion?";
$TEXT[79]	=	"Vil du virkelig tømme denne tabel?";
$TEXT[80]	=	"Vil du virkelig slette denne tabel?";
$TEXT[81]	=	"Tilføj";
$TEXT[82]	=	"Vil du virkelig slette dette view?";
$TEXT[83]	=	"Vil du virkelig slette denne trigger?";
$TEXT[84]	=	"Værktøjer";
$TEXT[85]	=	"Vil du virkelig slette denne database? Denne sletning fjerner blot basen fra udvalgslisten, databasen ødelægges ikke.  ";
$TEXT[86]	=	"Slet";
$TEXT[87]	=	"Tilføj nyt View";
$TEXT[88]	=	"Tilføj ny Trigger";
$TEXT[89]	=	"Tilføj ny Function";
$TEXT[90]	=	"SQL forespørgsel";
$TEXT[91]	=	"Key navn";
$TEXT[92]	=	"Vil du virkelig slette dette Index";
$TEXT[93]	=	"Tilføj et Index til";
$TEXT[94]	=	"kolonne(r)";
$TEXT[95]	=	"Ignorer";
$TEXT[96]	=	"Add on the key";
$TEXT[97]	=	"Opret et View med navnet ";
$TEXT[98]	=	"fra denne forespørgsel.";
$TEXT[99]	=	"Fejl linie(r)";
$TEXT[100]	=	"Der er bestemt et problem med skriverettighederne på konfigurationsdatabase";
$TEXT[101]	=	"Denne database kan hverken oprettes eller læses";
$TEXT[102]	=	"Alle felter skal være udfyldt!";
$TEXT[103]	=	"Tilføj ny database";
$TEXT[104]	=	"Sti";
$TEXT[105]	=	"Data array har ikke et konstant antal elementer";
$TEXT[106]	=	"Parametre for constructor class 'Grid' skal være et array";
$TEXT[107]	=	"The column alignement array doesn't haven't a good number of element.";
$TEXT[108]	=	"Cellers alignment skal være : 'left', 'right' eller 'center'";
$TEXT[109]	=	"Kolonners alignment parametre skal være et array";
$TEXT[110]	=	"Kolonners format parametre skal være et array";
$TEXT[111]	=	"The column sort array doesn't haven't a good number of element.";
$TEXT[112]	=	"Sorterings parametre skal være 0=ingen sortering, eller 1=sortering.";
$TEXT[113]	=	"Kolonners sorteringsparametre skal være et array";
$TEXT[114]	=	"The format string for the calculate column is empty.";
$TEXT[115]	=	"The title is obligatory for a calculate column.";
$TEXT[116]	=	"Parametre til constructor class 'ArrayToGrid' skal være et array.";
$TEXT[117]	=	"Det kan ikke lade sig gøre at tælle record antal";
$TEXT[118]	=	"Antal records";
$TEXT[119]	=	"Indsæt";
$TEXT[120]	=	"Er du sikker på at du vil slette";
$TEXT[121]	=	"the";
$TEXT[122]	=	"the";
$TEXT[123]	=	"Er du sikker på at du vil tømme denne tabel";
$TEXT[124]	=	"Kun struktur";
$TEXT[125]	=	"Struktur og data";
$TEXT[126]	=	"Kun data";
$TEXT[127]	=	"Komplette indsættelser";
$TEXT[128]	=	"send";
$TEXT[129]	=	"Host";
$TEXT[130]	=	"Generation Time";
$TEXT[131]	=	"Database";
$TEXT[132]	=	"Tabelstruktur for tabel";
$TEXT[133]	=	"Dumper data for tabel";
$TEXT[134]	=	"View-struktur for view";
$TEXT[135]	=	"Egenskaber for brugerdefineret funktion";
$TEXT[136]	=	"Records";
$TEXT[137]	=	"Fil";
$TEXT[138]	=	"Udskift indhold";
$TEXT[139]	=	"Separator";
$TEXT[140]	=	"Indsæt data fra tekstformatteret fil";
$TEXT[141]	=	"Sprog";
$TEXT[142]	=	"Tema";
$TEXT[143]	=	"Upload database";
$TEXT[144]	=	"Uploadmappe er ikke tilgængelig.<br>(Modificer konstanten 'DEFAULT_DB_PATH' i filen 'include/user_defined.inc.php')";
$TEXT[145]	=	"Explain SQL";
$TEXT[146]	=	"Administration af tilknyttede databaser";
$TEXT[147]	=	"Her er ikke fri adgang.Indtast venligst gyldig brugernavn og password.";
$TEXT[148]	=	"Dette login er ugyldigt.";
$TEXT[149]	=	"Password passer ikke sammen med login.";
$TEXT[150]	=	"PHP version";
$TEXT[151]	= 	"After save";
$TEXT[152]	= 	"Retur til forrige side";
$TEXT[153]	= 	"Indsæt en anden ny række";
$TEXT[154]	= 	"Konfigurationsdatabasen er skrivebeskyttet.<br>Visse af SQLiteManagers funktioner er derfor ude af stand til at kunne fungere korrekt.";
$TEXT[155]	= 	"Databasen er skrivebeskyttet.";
$TEXT[156]	= 	"Privilegier"; 
$TEXT[157]	= 	"Udskift password"; 
$TEXT[158]	= 	"Log ud"; 
$TEXT[159]	= 	"Tilføj bruger"; 
$TEXT[160]	= 	"Tilføj gruppe"; 
$TEXT[161]	= 	"Brugeroversigt"; 
$TEXT[162]	= 	"Gruppeoversigt"; 
$TEXT[163]	= 	"Navn"; 
$TEXT[164]	= 	"Login"; 
$TEXT[165]	= 	"Gruppe"; 
$TEXT[166]	= 	"execSQL"; 
$TEXT[167]	= 	"data"; 
$TEXT[168]	= 	"eksport"; 
$TEXT[169]	= 	"tøm"; 
$TEXT[170]	= 	"slet"; 
$TEXT[171]	= 	"Gammelt password er ikke korrekt."; 
$TEXT[172]	= 	"Password og bekræftelse er forskellige."; 
$TEXT[173]	= 	"Password blev ændret"; 
$TEXT[174]	= 	"Klik her for logon igen"; 
$TEXT[175]	= 	"Gammel :"; 
$TEXT[176]	= 	"Ny :"; 
$TEXT[177]	= 	"Bekræft :"; 
$TEXT[178]	= 	"Information"; 
$TEXT[179]	= 	"Placering :"; 
$TEXT[180]	= 	"Størrelse :"; 
$TEXT[181]	= 	"Rettigheder :"; 
$TEXT[182]	= 	"Senest modificeret :"; 
$TEXT[183]	= 	"Integritetstjek"; 
$TEXT[184]	= 	"Vacuum"; 
$TEXT[185]	= 	"Standard synkronisering :"; 
$TEXT[186]	= 	"Standard cache_size :"; 
$TEXT[187]	= 	"FRA "; 
$TEXT[188]	= 	"NORMAL "; 
$TEXT[189]	= 	"FULD "; 
$TEXT[190]	= 	"Administration af adgangskontrol"; 
$TEXT[191]	= 	"Ja"; 
$TEXT[192]	= 	"Nej"; 
$TEXT[193]	= 	"Standard midlertidig opbevaring"; 
$TEXT[194]	= 	"STANDARD"; 
$TEXT[195]	= 	"HUKOMMELSE"; 
$TEXT[196]	= 	"FIL"; 
$TEXT[197]	= 	"Unique"; 
$TEXT[198]	= 	"Index"; 
$TEXT[199]	= 	"Data"; 
$TEXT[200]	= 	"Udfør";
$TEXT[201]	=	"Udvalg";
$TEXT[202]	=	"Operator";
$TEXT[203]	=	"additional condition :";
$TEXT[204]	=	"AND";
$TEXT[205]	=	"OR";
$TEXT[206]	=	"Select";
$TEXT[207]	=	"Search";
$TEXT[208]	=	"Rename";
$TEXT[209]	=	"Move";
$TEXT[210]	=	"Copy";
$TEXT[211]	=	"Plugins";
$TEXT[212]	=	"Maintenance";
$TEXT[213]	=	"Query time :";
$TEXT[214]	=	"msec.";
$TEXT[215]	=	"Rename table to :";
$TEXT[216]	=	"Move table to (database.table) :";
$TEXT[217]	=	"Copy table to (database.table) :";
$TEXT[218]	=	"Add DROP TABLE";
$TEXT[219]	=	"Save as New Row";
$TEXT[220]	=	"Save";
$TEXT[221]	=	"Save Type";
$TEXT[222]  =   "Operation";
$TEXT[223]  =   "Update";
$TEXT[224]  =   "Tip : You can use internal PHP functions in your queries !";
$TEXT[225]  =   "Truncated text";
$TEXT[226]  =   "Full text";
$TEXT[227]  =   "-- select --";
$TEXT[228]  =   "(s)";
$TEXT[229]  =   "Version";
$TEXT[230]  =   "(new database)";
$TEXT[231]  =   "Official SQliteManager Homepage";
$TEXT[232]  =   "The database can't be attain";
$TEXT[233]  =   "Trigger structure";
?>