<?php
/**
* Web based SQLite management
* @package SQLiteManager
* @version $Id: german.inc.php,v 1.36 2006/04/14 15:16:52 freddy78 Exp $ $=
Revision: 1.10 $
*/
$charset = 'iso-8859-1';
$langSuffix = 'de';
/**
* Fichier d'internationnalisation
*/

$itemTranslated = array("Table"   => "Tabelle",
                        "View"    => "Sicht",
                        "Trigger" => "Trigger",
                        "Function"  => "Funktion");

$langueTranslated = array(  1=>"Franz&ouml;sisch", 2=>"Englisch", 3=>"Polnisch", 4=>"Deutsch",
                            5=>"Japanisch", 6=>"Italienisch", 7=>"Kroatisch",
                            8=>"Brasilianisches Portugiesisch", 9=>"Niederl&auml;ndisch",
              				10=>"Spanisch", 11=>"D&auml;nisch", 12=>"Chinese traditional", 
              				13=>"Chinese simplified");

$themeTranslated = array("default"=>"Standard", "PMA"=>"PMA", "jall"=>"JALL", "green"=>"Gr&uuml;n");


$TEXT[1]  = "Home";
$TEXT[2]  = "Willkommen zu <a href=\"http://www.sqlitemanager.org\" target=\"_blank\">SQLiteManager</a> Version";
$TEXT[3]  = "SQLite Version";
$TEXT[4]  = "SQLite Dokumentation";
$TEXT[5]  = "SQL Sprache";
$TEXT[6]  = "Die SQLite-Extension kann nicht geladen werden.";
$TEXT[7]  = "Die SQLiteManager Konfigurations-Datenbank kann nicht ge&ouml;ffnet werden.<br>Fehlermeldung";
$TEXT[8]  = "Es besteht keine Schreib-Erlaubnis f&uuml;r die Konfigurations-Datenbank!";
$TEXT[9]  = "Fehler";
$TEXT[10] = "Funktion";
$TEXT[11] = "Aggregat";
$TEXT[12] = "Final function";
$TEXT[13] = "Anzahl Argumente";
$TEXT[14] = "Bearbeiten";
$TEXT[15] = "L&ouml;schen";
$TEXT[16] = "Eigenschaften der neuen Funktion";
$TEXT[17] = "Funktions-Eigenschaften";
$TEXT[18] = "Fehler: Alle Felder m&uuml;ssen ausgef&uuml;llt werden.";
$TEXT[19] = "Name";
$TEXT[20] = "Typ";
$TEXT[21] = "Step Properties";
$TEXT[22] = "Final Properties";
$TEXT[23] = "Argument-Anzahl";
$TEXT[24] = "Diese Funktion in allen Datenbanken erg&auml;nzen";
$TEXT[25] = "Eigenschaften der neuen Tabelle";
$TEXT[26] = "Eigenschaften der Tabelle";
$TEXT[27] = "Feld";
$TEXT[28] = "Typ";
$TEXT[29] = "L&auml;nge";
$TEXT[30] = "Null";
$TEXT[31] = "Standard";
$TEXT[32] = "Prim&auml;rschl&uuml;ssel";
$TEXT[33] = "Aktion";
$TEXT[34] = "Alle ausw&auml;hlen";
$TEXT[35] = "Auswahl entfernen";
$TEXT[36] = "markierte";
$TEXT[37] = "Sind Sie sicher, daß Sie diese(s) Feld(er) l&ouml;schen m&ouml;chten?";
$TEXT[38] = "Indizes verwalten";
$TEXT[39] = "Sind Sie sicher, daß Sie dieses Feld l&ouml;schen m&ouml;chten?";
$TEXT[40] = "Ja";
$TEXT[41] = "Nein";
$TEXT[42] = "Primary";
$TEXT[43] = "Hinzuf&uuml;gen";
$TEXT[44] = "Feld(er)"; // "Feld(er) hinzuf&uuml;gen" would be better in SQLiteTableProperties.class.php
$TEXT[45] = "An das Ende der Tabelle";
$TEXT[46] = "An den Anfang der Tabelle";
$TEXT[47] = "Nach";
$TEXT[48] = "Neuen Datensatz einf&uuml;gen";
$TEXT[49] = "Datensatz bearbeiten";
$TEXT[50] = "Wert";
$TEXT[51] = "Speichern";
$TEXT[52] = "Daten aus einer Datei einf&uuml;gen";
$TEXT[53] = "Trigger";
$TEXT[54] = "Eigenschaften des neuen Triggers";
$TEXT[55] = "Eigenschaften des Triggers";
$TEXT[56] = "Zeitpunkt";
$TEXT[57] = "Ereignis";
$TEXT[58] = "In";
$TEXT[59] = "Bedingung";
$TEXT[60] = "Abfrage(n)";
$TEXT[61] = "Struktur";
$TEXT[62] = "Eigenschaften der neuen Sicht";
$TEXT[63] = "Eigenschaften der Sicht";
$TEXT[64] = "Es wurde keine Abfrage ausgef&uuml;hrt!";
$TEXT[65] = "Bad resource connection!";
$TEXT[66] = "SQL-Befehl(e) in der Datenbank ausf&uuml;hren";
$TEXT[67] = "<i>Oder</i> aus einer SQL-Datei";
$TEXT[68] = "Abfrage-Format: Standard (SQLite)";
$TEXT[69] = "Ausf&uuml;hren";
$TEXT[70] = "Die Abfrage wurde ausgef&uuml;hrt.";
$TEXT[71] = "Line has been modified.";
$TEXT[72] = "Struktur";
$TEXT[73] = "Anzeigen";
$TEXT[74] = "SQL";
$TEXT[75] = "Einf&uuml;gen";
$TEXT[76] = "Exportieren";
$TEXT[77] = "Leeren";
$TEXT[78] = "Sind Sie sicher, daß Sie diese Funktion l&ouml;schen m&ouml;chten?";
$TEXT[79] = "Sind Sie sicher, daß Sie diese Tabelle leeren m&ouml;chten?";
$TEXT[80] = "Sind Sie sicher, daß Sie diese Tabelle l&ouml;schen m&ouml;chten?";
$TEXT[81] = "Hinzuf&uuml;gen";
$TEXT[82] = "Sind Sie sicher, daß Sie diese Sicht l&ouml;schen m&ouml;chten?";
$TEXT[83] = "Sind Sie sicher, daß Sie diesen Trigger l&ouml;schen m&ouml;chten?";
$TEXT[84] = "Optionen";
$TEXT[85] = "Sind Sie sicher, daß Sie diese Datenbank l&ouml;schen m&ouml;chten? (Hinweis: Es wird nur der Verweis auf die Datenbank entfernt, nicht die Datenbank-Datei selbst.)";
$TEXT[86] = "L&ouml;schen";
$TEXT[87] = "Neue Sicht anlegen";
$TEXT[88] = "Neuen Trigger anlegen";
$TEXT[89] = "Neue Funktion anlegen";
$TEXT[90] = "SQL-Abfrage";
$TEXT[91] = "Name des Schl&uuml;ssels";
$TEXT[92] = "M&ouml;chten Sie diesen Index wirklich l&ouml;schen?";
$TEXT[93] = "Index &uuml;ber ";
$TEXT[94] = "Spalte(n) anlegen";
$TEXT[95] = "Ignorieren";
$TEXT[96] = "Add on the key";
$TEXT[97] = "Eine Sicht namens ";
$TEXT[98] = "aus dieser Abfrage anlegen.";
$TEXT[99] = "Fehlerzeile(n)";
$TEXT[100]  = "Wahrscheinlich fehlen Schreib-Rechte f&uuml;r die Konfigurations-Datenbank.";
$TEXT[101]  = "Anlegen oder Lesen dieser Datenbank ist nicht m&ouml;glich";
$TEXT[102]  = "Es m&uuml;ssen alle Felder ausgef&uuml;llt werden!";
$TEXT[103]  = "Neue Datenbank anlegen";
$TEXT[104]  = "Pfad";
$TEXT[105]  = "The data array has not a constante number of element";
$TEXT[106]  = "Dem Konstuktor der Klasse 'Grid' muß ein Array &uuml;bergeben werden.";
$TEXT[107]  = "The column alignment array doesn't haven't a good number of element.";
$TEXT[108]  = "Die Zellen-Ausrichtung muß einen der folgenden Werte besitzen: 'left', 'right' oder 'center'";
$TEXT[109]  = "The paramaters for the columns alignement must be an array";
$TEXT[110]  = "The paramaters for the columns format must be an array";
$TEXT[111]  = "The column sort array doesn't haven't a good number of element.";
$TEXT[112]  = "The sort paramaters must be 0=no sort, Or 1=sort.";
$TEXT[113]  = "The paramaters for the columns sort must be an array";
$TEXT[114]  = "Der Format-String f&uuml;r die berechnete Spalte ist leer.";
$TEXT[115]  = "Der Titel der berechneten Spalte ist erforderlich.";
$TEXT[116]  = "Dem Konstuktor der Klasse 'ArrayToGrid' muß ein Array &uuml;bergeben werden.";
$TEXT[117]  = "Die Datensatz-Anzahl kann nicht ermittelt werden.";
$TEXT[118]  = "Eintr&auml;ge";
$TEXT[119]  = "Einf&uuml;gen";
$TEXT[120]  = "Sind Sie sicher, daß Sie l&ouml;schen m&ouml;chten: ";
$TEXT[121]  = "the";
$TEXT[122]  = "the";
$TEXT[123]  = "Sind Sie sicher, daß Sie diese Tabelle leeren m&ouml;chten";
$TEXT[124]  = "Nur die Struktur";
$TEXT[125]  = "Struktur und Daten";
$TEXT[126]  = "Nur Daten";
$TEXT[127]  = "Vollst&auml;ndige INSERTs";
$TEXT[128]  = "senden";
$TEXT[129]  = "Host";
$TEXT[130]  = "Erzeugungszeit";
$TEXT[131]  = "Datenbank";
$TEXT[132]  = "Tabellenstruktur f&uuml;r Tabelle";
$TEXT[133]  = "Auslesen der Daten von Tabelle ";
$TEXT[134]  = "Struktur der Sicht ansehen";
$TEXT[135]  = "Eigenschaften benutzerdefinierter Funktion";
$TEXT[136]  = "Datens&auml;tze";
$TEXT[137]  = "Datei";
$TEXT[138]  = "Inhalt ersetzen";
$TEXT[139]  = "Trennzeichen";
$TEXT[140]  = "Daten aus Text-Datei einf&uuml;gen";
$TEXT[141]  = "Sprache";
$TEXT[142]  = "Theme (Oberfl&auml;che)";
$TEXT[143]  = "Datenbank hochladen";
$TEXT[144]  = "Das Datei-Upload-Verzeichnis kann nicht benutzt werden.<br>(Bitte &auml;ndern Sie die Konstante 'DEFAULT_DB_PATH' in der Datei 'include/user_defined.inc.php')";
$TEXT[145]  = "SQL erkl&auml;ren";
$TEXT[146]  = "Verk&uuml;pfte (attached) Datenbanken verwalten";
$TEXT[147]  = "Sie sind nicht berechtigt, hierauf zuzugreifen. Sie m&uuml;ßen einen g&uuml;ltigen Benutzernamen und das dazugeh&ouml;rige Paßwort eingeben.";
$TEXT[148]  = "Dieser Benutzername ist ung&uuml;ltig.";
$TEXT[149]  = "Dieses Paßwort paßt nicht zum Benutzernamen.";
$TEXT[150]  = "PHP Version";
$TEXT[151] =  "Nach dem Speichern";
$TEXT[152] =  "Zur&uuml;ck zur vorherigen Seite";
$TEXT[153] =  "Einen weiteren Datensatz einf&uuml;gen";
$TEXT[154] =  "Die Konfigurationsdatenbank ist schreibgesch&uuml;tzt.<br>Einige Funktionen des SQLiteManagers k&ouml;nnen nicht korrekt arbeiten.";
$TEXT[155] =  "Die Datenbank ist schreibgesch&uuml;tzt.";
$TEXT[156] =  "Rechte";
$TEXT[157] =  "Paßwort &auml;ndern";
$TEXT[158] =  "Abmelden";
$TEXT[159] =  "Nutzer hinzuf&uuml;gen";
$TEXT[160] =  "Gruppe hinzuf&uuml;gen";
$TEXT[161] =  "Nutzer&uuml;bersicht";
$TEXT[162] =  "Gruppen&uuml;bersicht";
$TEXT[163] =  "Name";
$TEXT[164] =  "Anmelden";
$TEXT[165] =  "Gruppe";
$TEXT[166] =  "execSQL";
$TEXT[167] =  "data";
$TEXT[168] =  "export";
$TEXT[169] =  "empty";
$TEXT[170] =  "del";
$TEXT[171] =  "Das alte Paßwort ist falsch.";
$TEXT[172] =  "Paßwort und Paßwortbest&auml;tigung sind unterschiedlich.";
$TEXT[173] =  "Das Paßwort wurde ge&auml;ndert";
$TEXT[174] =  "Zur Neuanmeldung hier klicken";
$TEXT[175] =  "Alt:";
$TEXT[176] =  "Neu:";
$TEXT[177] =  "Best&auml;tigen:";
$TEXT[178] =  "Information";
$TEXT[179] =  "Pfad:";
$TEXT[180] =  "Gr&ouml;ße:";
$TEXT[181] =  "Rechte:";
$TEXT[182] =  "Letzte &Auml;nderung:";
$TEXT[183] =  "Integrit&auml;tspr&uuml;fung";
$TEXT[184] =  "Vacuum";
$TEXT[185] =  "Standard Synchronisation:";
$TEXT[186] =  "Standard Cachegr&ouml;ße (1 Seite belegt 1.5 kB RAM):";
$TEXT[187] =  "AUS";
$TEXT[188] =  "NORMAL";
$TEXT[189] =  "VOLL";
$TEXT[190]  =   "Zugriffskontrolle";
$TEXT[191]  =   "Ja";
$TEXT[192]  =   "Nein";
$TEXT[193]  =   "Standard Tempor&auml;rspeicher";
$TEXT[194]  =   "DEFAULT";
$TEXT[195]  =   "RAM";
$TEXT[196]  =   "DATEI";
$TEXT[197]  =   "Unique";
$TEXT[198]  =   "Index";
$TEXT[199]  =   "Daten";
$TEXT[200]  =   "Anwenden";
$TEXT[201]  = "Auswahl";
$TEXT[202]  = "Operator";
$TEXT[203]  = "zus&auml;tzliche Bedingung:";
$TEXT[204]  = "UND";
$TEXT[205]  = "ODER";
$TEXT[206]  = "Abfrageeditor";
$TEXT[207]  = "Suchen";
$TEXT[208]  = "Wiederernennen";
$TEXT[209]  = "Verschieben";
$TEXT[210]  = "Kopieren";
$TEXT[211]  = "Plugins";
$TEXT[212]  = "Wartung";
$TEXT[213]  = "Abfragezeit:";
$TEXT[214]  = "msec.";
$TEXT[215]  = "Tabelle umbenennen in:";
$TEXT[216]  = "Verschiebe Tabelle nach (Datenbank.Tabellenname):";
$TEXT[217]  = "Kopiere Tabelle nach (Datenbank.Tabellenname):";
$TEXT[218]  = "Mit 'DROP TABLE'  ";
$TEXT[219]  = "Als neuen Datensatz speichern";
$TEXT[220]  = "Speichern";
$TEXT[221]  = "Art des Speicherns";
$TEXT[222]  =   "Operationen";
$TEXT[223]  =   "Aktualisieren";
$TEXT[224]  =   "Tipp: Sie k&ouml;nnen auch interne PHP Funktionen in Ihren Abfragen benutzen!";
$TEXT[225]  =   "gek&uuml;rzte Textfelder";
$TEXT[226]  =   "vollst&auml;ndige Textfelder";
$TEXT[227]  =   "-- ausw&auml;hlen --";
$TEXT[228]  =   "(n)";
$TEXT[229]  =   "Version";
$TEXT[230]  =   "(new database)";
$TEXT[231]  =   "Official SQliteManager Homepage";
$TEXT[232]  =   "The database can't be attain";
$TEXT[233]  =   "Trigger structure";
?>