<?php 
// ================================================
// SPAW PHP WYSIWYG editor control
// ================================================
// Slovak language file
// ================================================
// Developed: Alan Mendelevich, alan@solmetra.lt
// Copyright: Solmetra (c)2003 All rights reserved.
// Slovak translation: Pavel Koutny
//                     pavel.koutny@inetix.sk
// ------------------------------------------------
//                                www.solmetra.com
// ================================================
// v.1.0, 2003-03-20
// ================================================

// charset to be used in dialogs
$spaw_lang_charset = 'iso-8859-2';

// language text data array
// first dimension - block, second - exact phrase
// alternative text for toolbar buttons and title for dropdowns - 'title'

$spaw_lang_data = array(
  'cut' => array(
    'title' => 'Vystrihnúť'
  ),
  'copy' => array(
    'title' => 'Kopírovať'
  ),
  'paste' => array(
    'title' => 'Vložiť'
  ),
  'undo' => array(
    'title' => 'Vrátiť'
  ),
  'redo' => array(
    'title' => 'Vykonať'
  ),
  'hyperlink' => array(
    'title' => 'Hyperlink'
  ),
  'image_insert' => array(
    'title' => 'Vložiť obrázok',
    'select' => 'Vybrať',
    'cancel' => 'Zrušiť',
    'library' => 'Knižnica',
    'preview' => 'Náhľad',
    'images' => 'Obrázky',
    'upload' => 'Nahrať obrázek',
    'upload_button' => 'Nahrať',
    'error' => 'Chyba',
    'error_no_image' => 'Vyberte prosím obrázok',
    'error_uploading' => 'V priebehu nahrávania došlo k chybe. Zopakujte to.',
    'error_wrong_type' => 'chybný formát obrázku',
    'error_no_dir' => 'Knižnica neexistuje',
  ),
  'image_prop' => array(
    'title' => 'Vlastnosti obrázku',
    'ok' => '   OK   ',
    'cancel' => 'Zrušiť',
    'source' => 'Zdroj',
    'alt' => 'Alternatívny text',
    'align' => 'Zarovnanie',
    'left' => 'vľevo',
    'right' => 'vpravo',
    'top' => 'Zhora',
    'middle' => 'Na stred',
    'bottom' => 'Zdole',
    'absmiddle' => 'absolútny stred',
    'texttop' => 'text-hore',
    'baseline' => 'Základná linka',
    'width' => 'Šírka',
    'height' => 'Výška',
    'border' => 'Okraje',
    'hspace' => 'Hor. medzera',
    'vspace' => 'Vert. medzera',
    'error' => 'Chyba',
    'error_width_nan' => 'Šírka nie je číslo',
    'error_height_nan' => 'Výška nie je číslo',
    'error_border_nan' => 'Okraj nie je číslo',
    'error_hspace_nan' => 'Horizontálna medzera nie je číslo',
    'error_vspace_nan' => 'Vertikálna medzera nie je číslo',
  ),
  'hr' => array(
    'title' => 'Horizontálny oddelovač'
  ),
  'table_create' => array(
    'title' => 'Vytvor tabuľku'
  ),
  'table_prop' => array(
    'title' => 'Vlastnosti tabuľky',
    'ok' => '   OK   ',
    'cancel' => 'Zrušiť',
    'rows' => 'Riadkov',
    'columns' => 'Stĺpcov',
    'width' => 'Šírka',
    'height' => 'Výška',
    'border' => 'Okraje',
    'pixels' => 'pixelov',
    'cellpadding' => 'Odsadenie v bunke',
    'cellspacing' => 'Vzdialenosť buniek',
    'bg_color' => 'Farba pozadia',
    'error' => 'Chyba',
    'error_rows_nan' => 'Riadky nie sú číslo',
    'error_columns_nan' => 'Stĺpce nie sú číslo',
    'error_width_nan' => 'Šírka nie je číslo',
    'error_height_nan' => 'Výška nie je číslo',
    'error_border_nan' => 'Okraj nie je číslo',
    'error_cellpadding_nan' => 'Odsadenie v bunke nie je číslo',
    'error_cellspacing_nan' => 'Vzdialenosť buniek nie je číslo',
  ),
  'table_cell_prop' => array(
    'title' => 'Vlastnosti bunky',
    'horizontal_align' => 'Horizontálne zarovnanie',
    'vertical_align' => 'Vertikálne zarovnanie',
    'width' => 'Šírka',
    'height' => 'Výška',
    'css_class' => 'CSS trieda',
    'no_wrap' => 'nezalamovať',
    'bg_color' => 'Farba pozadia',
    'ok' => '   OK   ',
    'cancel' => 'Zrušiť',
    'left' => 'Vľevo',
    'center' => 'V strede',
    'right' => 'Vpravo',
    'top' => 'Zhora',
    'middle' => 'Na stred',
    'bottom' => 'Zdola',
    'baseline' => 'Základná linka',
    'error' => 'Chyba',
    'error_width_nan' => 'Šírka nie je číslo',
    'error_height_nan' => 'Výška nie je číslo',
    
  ),
  'table_row_insert' => array(
    'title' => 'Vložiť riadok'
  ),
  'table_column_insert' => array(
    'title' => 'Vložiť stĺpec'
  ),
  'table_row_delete' => array(
    'title' => 'Vymaž riadok'
  ),
  'table_column_delete' => array(
    'title' => 'Vymaž stĺpec'
  ),
  'table_cell_merge_right' => array(
    'title' => 'Zlúšiť vpravo'
  ),
  'table_cell_merge_down' => array(
    'title' => 'Zlúčiť nadol'
  ),
  'table_cell_split_horizontal' => array(
    'title' => 'Rozdeliť bunku horizontálne'
  ),
  'table_cell_split_vertical' => array(
    'title' => 'Rozdeliť bunku vertikálne'
  ),
  'style' => array(
    'title' => 'Štýl'
  ),
  'font' => array(
    'title' => 'Font'
  ),
  'fontsize' => array(
    'title' => 'Veľkosť'
  ),
  'paragraph' => array(
    'title' => 'Odstavec'
  ),
  'bold' => array(
    'title' => 'Tučné'
  ),
  'italic' => array(
    'title' => 'Šikmé'
  ),
  'underline' => array(
    'title' => 'Podčiarknuté'
  ),
  'ordered_list' => array(
    'title' => 'Číslovanie'
  ),
  'bulleted_list' => array(
    'title' => 'Odrážky'
  ),
  'indent' => array(
    'title' => 'Odsadenie'
  ),
  'unindent' => array(
    'title' => 'Zrušiť odsadenie'
  ),
  'left' => array(
    'title' => 'Vľavo'
  ),
  'center' => array(
    'title' => 'V strede'
  ),
  'right' => array(
    'title' => 'Vpravo'
  ),
  'fore_color' => array(
    'title' => 'Barva popredia'
  ),
  'bg_color' => array(
    'title' => 'Barva pozadia'
  ),
  'design_tab' => array(
    'title' => 'Prepnúť do WYSIWYG módu'
  ),
  'html_tab' => array(
    'title' => 'Přepnúť do HTML módu'
  ),
  'colorpicker' => array(
    'title' => 'Paleta farieb',
    'ok' => '   OK   ',
    'cancel' => 'Zrušiť',
  ),
  // <<<<<<<<< NEW >>>>>>>>>
  'cleanup' => array(
    'title' => 'HTML kontrola (odstraní štýly)',
    'confirm' => 'Prevedením akcie odstránite všetky štýly, fonty a zbytočné tagy z aktuálneho obsahu. Jedno, alebo všetky formátovania budú odstránené.',
    'ok' => '   OK   ',
    'cancel' => 'Zrušiť',
  ),
  'toggle_borders' => array(
    'title' => 'Upraviť okraje',
  ),
  'hyperlink' => array(
    'title' => 'Hyperlink',
    'url' => 'URL',
    'name' => 'Meno',
    'target' => 'Cieľ',
    'title_attr' => 'Názov',
    'ok' => '   OK   ',
    'cancel' => 'Zrušiť',
  ),
  'table_row_prop' => array(
    'title' => 'Vlastnosti riadku',
    'horizontal_align' => 'Horizontálne zarovnanie',
    'vertical_align' => 'Vertikálne zarovnanie',
    'css_class' => 'CSS trieda',
    'no_wrap' => 'Nezalamovať',
    'bg_color' => 'Farba pozadia',
    'ok' => '   OK   ',
    'cancel' => 'Zrušiť',
    'left' => 'Vľevo',
    'center' => 'V strede',
    'right' => 'Vpravo',
    'top' => 'Zhora',
    'middle' => 'Na stred',
    'bottom' => 'Zdola',
    'baseline' => 'Základná linka',
  ),
  'symbols' => array(
    'title' => 'Špeciálne znaky',
    'ok' => '   OK   ',
    'cancel' => 'Zrušiť',
  ),
  'symbols' => array(
    'title' => 'Špeciálne znaky',
    'ok' => '   OK   ',
    'cancel' => 'Zrušiť',
  ),
  'templates' => array(
    'title' => 'Šablóny',
  ),
  'page_prop' => array(
    'title' => 'Vlastnosti stránky',
    'title_tag' => 'Názov',
    'charset' => 'Kódovanie',
    'background' => 'Obrázok pozadia',
    'bgcolor' => 'Farba pozadia',
    'text' => 'Farba textu',
    'link' => 'Farba odkazu',
    'vlink' => 'Farba navštíveného odkazu',
    'alink' => 'Farba aktívneho odkazu',
    'leftmargin' => 'Ľavý okraj',
    'topmargin' => 'Horný okraj',
    'css_class' => 'CSS trieda',
    'ok' => '   OK   ',
    'cancel' => 'Zrušiť',
  ),
  'preview' => array(
    'title' => 'Náhľad',
  ),
  'image_popup' => array(
    'title' => 'Prekrývanie obrázkov',
  ),
  'zoom' => array(
    'title' => 'Zväčšenie',
  ),
);
?>

