<?php
/**
* Web based SQLite management
* @package SQLiteManager
* @version $Id: simplified_chinese.inc.php,v 1.2 2006/04/14 15:16:52 freddy78 Exp $ $Revision: 1.2 $
* @version $Id: simplified_chinese.inc.php,v 1.2 2006/04/14 15:16:52 freddy78 Exp $Revision: 1.2 $
*/
$charset = 'GB2312';
$langSuffix = 'sz';
/**
* Fichier d'internationnalisation
*/
$itemTranslated = array(	"Table"		=> "表格", 
							"View"		=> "视图",
							"Trigger"	=> "触发器",
							"Function"	=> "函数");

$langueTranslated = array(	1=>"法语", 2=>"英语", 3=>"波兰语", 
							4=>"德语", 5=>"倭语", 6=>"意大利语", 
							7=>"克罗地亚语", 8=>"巴西葡萄牙语", 9=>"荷兰语", 
							10=>"西班牙语", 11=>"丹麦语",12=>"简体中文",13=>"繁体中文");

$themeTranslated = array("default"=>"默认", "green"=>"绿色", "PMA"=>"PMA", "jall"=>"Jall");

$TEXT[1]	=	"主页";
$TEXT[2]	=	"欢迎使用<a href=\"http://www.sqlitemanager.org\" target=\"_blank\">SQLiteManager</a> 版本";
$TEXT[3]	=	"SQLite版本";
$TEXT[4]	=	"SQLite文档";
$TEXT[5]	=	"SQL语言";
$TEXT[6]	=	"SQLite扩展没有加载.";
$TEXT[7]	=	"打不开'SQLite'配置数据库.<br>错误消息";
$TEXT[8]	=	"配置数据库没有'写'权限!";
$TEXT[9]	=	"错误";
$TEXT[10]	=	"函数";
$TEXT[11]	=	"聚合";
$TEXT[12]	=	"Final function";
$TEXT[13]	=	"Nb Args";
$TEXT[14]	=	"修改";
$TEXT[15]	=	"删除";
$TEXT[16]	=	"新函数属性";
$TEXT[17]	=	"函数属性";
$TEXT[18]	=	"错误: 必有字段都有必须填入值.";
$TEXT[19]	=	"名称";
$TEXT[20]	=	"类型";
$TEXT[21]	=	"步骤属性";
$TEXT[22]	=	"最后属性";
$TEXT[23]	=	"Nb 参数";
$TEXT[24]	=	"将此函数应用到所有数据库.";
$TEXT[25]	=	"新建表属性";
$TEXT[26]	=	"表格属性";
$TEXT[27]	=	"字段";
$TEXT[28]	=	"类型";
$TEXT[29]	=	"长度";
$TEXT[30]	=	"空值";
$TEXT[31]	=	"默认值";
$TEXT[32]	=	"主键";
$TEXT[33]	=	"动作";
$TEXT[34]	=	"全选";
$TEXT[35]	=	"全不选";
$TEXT[36]	=	"为选择集";
$TEXT[37]	=	"你确定要删除掉这个/这些字段吗?";
$TEXT[38]	=	"管理索引(s)";
$TEXT[39]	=	"你确实想删除这个字段吗?";
$TEXT[40]	=	"是的";
$TEXT[41]	=	"不是";
$TEXT[42]	=	"主键";
$TEXT[43]	=	"添加";
$TEXT[44]	=	"字段(s)";
$TEXT[45]	=	"在表格的最后";
$TEXT[46]	=	"在表格的开头";
$TEXT[47]	=	"在下面字段之后:";
$TEXT[48]	=	"插入新记录";
$TEXT[49]	=	"修改一条记录";
$TEXT[50]	=	"值";
$TEXT[51]	=	"保存";
$TEXT[52]	=	"从文件中加载数据.";
$TEXT[53]	=	"触发器";
$TEXT[54]	=	"新建触发器属性";
$TEXT[55]	=	"触发器属性";
$TEXT[56]	=	"时刻";
$TEXT[57]	=	"事件";
$TEXT[58]	=	"在";
$TEXT[59]	=	"条件";
$TEXT[60]	=	"步骤";
$TEXT[61]	=	"属性";
$TEXT[62]	=	"新建视图属性";
$TEXT[63]	=	"视图属性";
$TEXT[64]	=	"没有执行任何查询!";
$TEXT[65]	=	"错误的资源链接!";
$TEXT[66]	=	"执行一个或多个 <b>请求(s)";
$TEXT[67]	=	"<i>或</i>自一个SQL文件";
$TEXT[68]	=	"查询格式 : 标准 (SQLite)";
$TEXT[69]	=	"执行";
$TEXT[70]	=	"查询已被执行.";
$TEXT[71]	=	"查询修改了行.";
$TEXT[72]	=	"结构";
$TEXT[73]	=	"显示";
$TEXT[74]	=	"SQL";
$TEXT[75]	=	"插入";
$TEXT[76]	=	"导出";
$TEXT[77]	=	"清空";
$TEXT[78]	=	"你真的想删除这个函数吗?";
$TEXT[79]	=	"你真的想清空这个表格吗?";
$TEXT[80]	=	"你真的想删除这个表格吗?";
$TEXT[81]	=	"添加";
$TEXT[82]	=	"你真的想删除这个视图吗?";
$TEXT[83]	=	"你真的想删除这个触发器吗?";
$TEXT[84]	=	"选项";
$TEXT[85]	=	"你真的确定要删除这个数据库吗? 这个删除操作只是断开SQLiteManager与数据库的连接,数据库本身不会被删除.  ";
$TEXT[86]	=	"删除";
$TEXT[87]	=	"添加一个新的视图";
$TEXT[88]	=	"添加一个新的触发器";
$TEXT[89]	=	"添加一个新的函数";
$TEXT[90]	=	"SQL查询";
$TEXT[91]	=	"键名";
$TEXT[92]	=	"你真的想删除这个索引吗?";
$TEXT[93]	=	"添加一个索引在";
$TEXT[94]	=	"列(s)";
$TEXT[95]	=	"忽视";
$TEXT[96]	=	"添加键";
$TEXT[97]	=	"新建一个视图并命名为";
$TEXT[98]	=	"从这个查询.";
$TEXT[99]	=	"错误行(s)";
$TEXT[100]	=	"肯定是由于配置信息数据库存在一个写权限的问题";
$TEXT[101]	=	"不能创建或读取这个数据库";
$TEXT[102]	=	"所有项都必须填入内容!";
$TEXT[103]	=	"创建或添加新数据库";
$TEXT[104]	=	"路径";
$TEXT[105]	=	"数据数组没有常量数字元素";
$TEXT[106]	=	"构造类'Grid'的参数必须是一个数组";
$TEXT[107]	=	"列排列数组不是没有合适的元素.(原文可能有误)";
$TEXT[108]	=	"单元格排列串必须是 : 'left', 'right' 或者 'center'";
$TEXT[109]	=	"列排列的参数必须是数组";
$TEXT[110]	=	"列格式的参数必须是数组";
$TEXT[111]	=	"列排序数组不是没有合适的元素.(原文可能有误)";
$TEXT[112]	=	"排序数组必须是 0=不排序, 或者是 1=排序.";
$TEXT[113]	=	"列排序的参数必须是一个数组";
$TEXT[114]	=	"计算列的格式字符串是空的.";
$TEXT[115]	=	"计算列的标题是必须的.";
$TEXT[116]	=	"构造类'ArrayToGrid' 的参数必须是一个数组.";
$TEXT[117]	=	"无法获得记录数";
$TEXT[118]	=	"Nb 记录";
$TEXT[119]	=	"插入";
$TEXT[120]	=	"你确定要删除";
$TEXT[121]	=	"此";
$TEXT[122]	=	"此";
$TEXT[123]	=	"你确定要清空这个表格吗?";
$TEXT[124]	=	"仅需结构";
$TEXT[125]	=	"结构和数据";
$TEXT[126]	=	"仅需数据";
$TEXT[127]	=	"完全插入格式";
$TEXT[128]	=	"发送";
$TEXT[129]	=	"主机";
$TEXT[130]	=	"生成时间";
$TEXT[131]	=	"数据库";
$TEXT[132]	=	"表格的表格结构";
$TEXT[133]	=	"从表格中导出数据";
$TEXT[134]	=	"视图的视图的结构";
$TEXT[135]	=	"用户自定义函数属性";
$TEXT[136]	=	"记录";
$TEXT[137]	=	"文件";
$TEXT[138]	=	"内容替换";
$TEXT[139]	=	"分格符";
$TEXT[140]	=	"从文本格式的文件来加载插入数据";
$TEXT[141]	=	"语言";
$TEXT[142]	=	"页面风格";
$TEXT[143]	=	"上传数据库";
$TEXT[144]	=	"上传目录不可访问.<br>(修改文件 'include/user_defined.inc.php'中的 'DEFAULT_DB_PATH'常量)";
$TEXT[145]	=	"解析SQL";
$TEXT[146]	=	"管理附属数据库";
$TEXT[147]	=	"此地你没有权限访问.你的登录名和密码不对.";
$TEXT[148]	=	"登录失败.";
$TEXT[149]	=	"该登录的登录名的密码不对.";
$TEXT[150]	=	"PHP版本";
$TEXT[151]	= 	"保存之后";
$TEXT[152]	= 	"返回前一页";
$TEXT[153]	= 	"添加另外新的一行";
$TEXT[154]	= 	"配置数据库只读.<br> SQLiteManager 的某些功能可能不能正常运行.";
$TEXT[155]	= 	"数据库只读.";
$TEXT[156]	= 	"权限"; 
$TEXT[157]	= 	"改变密码"; 
$TEXT[158]	= 	"登出"; 
$TEXT[159]	= 	"添加用哀恸"; 
$TEXT[160]	= 	"添加分组"; 
$TEXT[161]	= 	"查看用户"; 
$TEXT[162]	= 	"查看分组"; 
$TEXT[163]	= 	"名称"; 
$TEXT[164]	= 	"登录"; 
$TEXT[165]	= 	"分组"; 
$TEXT[166]	= 	"执行SQL"; 
$TEXT[167]	= 	"数据"; 
$TEXT[168]	= 	"导出"; 
$TEXT[169]	= 	"清空"; 
$TEXT[170]	= 	"删除"; 
$TEXT[171]	= 	"旧密码不对."; 
$TEXT[172]	= 	"密码与其确认不同."; 
$TEXT[173]	= 	"密码已修改"; 
$TEXT[174]	= 	"点击这里重新登录"; 
$TEXT[175]	= 	"旧的 :"; 
$TEXT[176]	= 	"新的 :"; 
$TEXT[177]	= 	"确认 :"; 
$TEXT[178]	= 	"信息"; 
$TEXT[179]	= 	"位置 :"; 
$TEXT[180]	= 	"大小 :"; 
$TEXT[181]	= 	"权限 :"; 
$TEXT[182]	= 	"最后修改 :"; 
$TEXT[183]	= 	"完整性检查"; 
$TEXT[184]	= 	"紧缩"; 
$TEXT[185]	= 	"默认同步 :"; 
$TEXT[186]	= 	"默认缓冲区大小:"; 
$TEXT[187]	= 	"关闭 "; 
$TEXT[188]	= 	"正常 "; 
$TEXT[189]	= 	"全部 "; 
$TEXT[190]	= 	"访问控制管理"; 
$TEXT[191]	= 	"是"; 
$TEXT[192]	= 	"否"; 
$TEXT[193]	= 	"默认临时存储"; 
$TEXT[194]	= 	"默认"; 
$TEXT[195]	= 	"内存"; 
$TEXT[196]	= 	"文件"; 
$TEXT[197]	= 	"唯一"; 
$TEXT[198]	= 	"索引"; 
$TEXT[199]	= 	"数据"; 
$TEXT[200]	= 	"应用";
$TEXT[201]	=	"选择";
$TEXT[202]	=	"操作符";
$TEXT[203]	=	"符加条件 :";
$TEXT[204]	=	"并且";
$TEXT[205]	=	"或者";
$TEXT[206]	=	"选择";
$TEXT[207]	=	"查询";
$TEXT[208]	=	"重命名";
$TEXT[209]	=	"移动";
$TEXT[210]	=	"复制";
$TEXT[211]	=	"插件";
$TEXT[212]	=	"维护";
$TEXT[213]	=	"查询时间 :";
$TEXT[214]	=	"毫秒.";
$TEXT[215]	=	"重命名到 :";
$TEXT[216]	=	"移动到(数据库.表) :";
$TEXT[217]	=	"复制到 (数据库.表) :";
$TEXT[218]	=	"添加删除表";
$TEXT[219]	=	"另存为新行";
$TEXT[220]	=	"保存";
$TEXT[221]	=	"保存类型";
$TEXT[222]  =   "操作";
$TEXT[223]  =   "更新";
$TEXT[224]  =   "提示:您可以在你的查询中使用PHP内部函数！";
$TEXT[225]  =   "截断文本";
$TEXT[226]  =   "全文";
$TEXT[227]  =   "-- 请选择 --";
$TEXT[228]  =   "(s)";
$TEXT[229]  =   "Version";
$TEXT[230]  =   "(new database)";
$TEXT[231]  =   "Official SQliteManager Homepage";
$TEXT[232]  =   "The database can't be attain";
$TEXT[233]  =   "Trigger structure";
?>