* { 
	font-family: Verdana, Tahoma, Arial, Helvetica, geneva, sans-serif;
	color: black;
}
body {
	background-color: #FAFFFA;
	background-image: url(pics/bg.png);
	font-size: 11px;
	margin:0px;
	overflow:auto;
	scrollbar-DarkShadow-Color: #326632;
	scrollbar-3dLight-Color		: #FAFFFA;
	scrollbar-Arrow-Color			: #326632;
	scrollbar-Base-Color			: #DDEEDD;
	scrollbar-Face-Color			: #7FC08F;
	scrollbar-Highlight-Color	: #7FC08F;
	scrollbar-Shadow-Color		: #7FC08F;
	scrollbar-Track-Color			: #DDEEDD;	
}
table.menu { 
  border: 0; 
  border-bottom: 1px groove; 
  background-color: white;
  text-align: left;
  padding: 0px;
  margin-bottom: 10px;
  width: 100%;
 	filter:progid:DXImageTransform.Microsoft.Shadow(color=#BDC3BD, Direction=180, Strength=2); 
}
table.menuButtons {
  width: 100%;
  text-align: left;
}
h4.serverinfo {
  padding: 2px;
  padding-left: 5px;
  border: 0; 
  border-bottom: 1px groove; 
  font-weight : normal;
  margin-bottom : 20px;
}
table.home, table.Insert, table.Index {
  border:0px;
  padding:0px;
	background: #DDEEDD;
	text-align: center;
}
table.home { 
  width: 95%;
}
table.Browse {
	background: #DDEEDD; margin-top: 10px;
}
td.BrowseSelect {
  padding-bottom: 5px;
}
table.home, table.Browse, table.Insert, table.Index, table.PrivGroupe, table.PrivUser {
	background: #DDEEDD;
	border:1px solid gray;
 	filter:progid:DXImageTransform.Microsoft.Shadow(color=#BDC3BD, Direction=135, Strength=2); 
}
table.PrivGroupe, table.PrivUser {
  margin : 5px;
  padding : 2px;
}
thead td.PrivUser {
}
caption a.Browse { font-size: 12px; padding-top: 5px; }
div.Rights { padding:5px; border:0; }
div.Rights div {
  font-size: 13px;  font-weight: bold;
}
table.query { 
  border:1px solid gray;
  border-bottom:1px solid white;
  border-right:1px solid white;
}
td.queryTitle {
  border-bottom:1px solid white;
  padding:3px; padding-left:5px;
}
td.queryBody {
  border-top:1px solid gray;
  padding:3px; padding-left:7px;
  font-family: monospace, arial;
}

.sqlsyntaxe { font-family: monospace, arial;}
.syntaxe_keyword { font-family: monospace, arial; font-weight: bold; color: #990099}
.syntaxe_function { font-family: monospace, arial; color: #FF0000}
.syntaxe_type { font-family: monospace, arial; color: #FF9900}
.syntaxe_variable { font-family: monospace, arial; color: #800000}
.syntaxe_digit { font-family: monospace, arial; color: red}
.syntaxe_string { font-family: monospace, arial; color: #008000}
.syntaxe_punct { font-family: monospace, arial; font-weight: bold; color: fuchsia}
hr {
  display: none;
}
div.BrowseOptions {
  width: 100%;
  text-align: center;
}
table.BrowseOption {
  width: 72%;
  text-align: left;
}
div.TableOptions { 
  width: 100%;
  text-align: center; 
}
div.Indexes { 
  width: 60%; 
  margin: 5px; 
  border: 0; 
  text-align: center; 
  align: center;
}

td.DisplayQuery {
  padding: 2px;
  padding-left: 3px;
}
td {
	font-size: 12px;
}
h2 {
	background-color: #DBEEE0;
	background-image: url(pics/bg_title.png); background-repeat: repeat-x;
	border-bottom: 1px solid #505550; 
	padding: 4px;
	font-weight: bold;
	font-family: Verdana, Tahoma, sans-serif, Helvetica, Arial;
	font-size: 13px;
	margin: 0;
}
td.boxtitlespace { 
	background: #7FC08F;
	background-image: url(pics/bg_th.png); 
	background-repeat: repeat-x;
  width: 2;
}
td.space {
  width: 2;
  border-right: 1px solid #FAFFFA; 
}
h4 {
	font-weight: bold;
	font-family: Verdana, Tahoma, sans-serif, Helvetica, Arial;
	font-size: 13px;
	margin: 0;
	margin-bottom: 5px;
}
thead, .tabproptitle, td.boxtitle {
	color:Black;
	font-size: 12px; 
	font-weight: bold; 
	height: 20px;
	padding: 2px;
	padding-left: 4px;
	background: #7FC08F;
	background-image: url(pics/bg_th.png); 
	background-repeat: repeat-x;
}
tfoot {
	color: #2F4F3F;
	font-weight: bold;
	border-left: 1px solid #DFE7DF; border-right: 1px solid #446644; 
	background: #7FC08F;
}
td.Browse, td.PrivUser, td.PrivGroupe  {
	font-size: 11px;
	border-bottom: 1px solid #505550; border-right: 1px solid #556655; 
	padding-left: 3px; padding-right: 3px;
}
td.tabproptitle, td.tabprop {
	border-bottom: 1px solid #505550; border-right: 1px solid #556655; 
}
div.BrowseImages {
  margin-top:1px;
}
tr.navbarre {
	color:#2F4F3F;
	height:20px;
	font-weight: bold;
	background: #7FC08F;
	background-image: url(pics/bg_th.png); 
	background-repeat: repeat-x;
}
tr.navbarre>td {
	height:20px;
}
fieldset {
	border-style: groove;
	font-size: 12px;
	padding: 10px; 
}
fieldset>table {
	margin-bottom: 10px;
}
legend {
	font-weight: bold;
	font-size: 12px;
}
input.button {
	color:#050;
	cursor:pointer;
	text-indent:0px;
	padding-left:5px;
	padding-right:3px;
	padding-top:0px;
	padding-bottom:2px;
	height:18px;
	margin-top: 4px; margin-left: 2px;
	font-family:Tahoma,helvetica,arial,sans-serif;
	font-size:11px;
	font-weight:bold;
	background-image: url(pics/bg_title.png); background-repeat: repeat-x;
	background-color:#9CEBAE;
	border:1px solid;
	border-color:#696;
	border-right-color:#363;
	border-bottom-color:#363;
	filter:progid:DXImageTransform.Microsoft.Shadow(color=#BDC3BD, Direction=135, Strength=1); 
}
input.button:hover {
  color:blue;
}

input.text, input.file {
  height:18px;
  font-size:11px;
  border: #f0fff0 1px solid;
  border-top:  #668066 1px solid;
  border-left: #668066 1px solid;  
  background-image: url(pics/input.png); background-repeat : repeat-x;
  background-position: top left;
}
input[type="text"] {
  height:18px;
  font-size:11px;
  border: #f0fff0 1px solid;
  border-top:  #668066 1px solid;
  border-left: #668066 1px solid;  
  background-image: url(pics/input.png); background-repeat : repeat-x;
  background-position: top left;
}
textarea {
  font-size:11px;
  border: #f0fff0 1px solid;
  border-top:  #668066 1px solid;
  border-left: #668066 1px solid;  
  background-image: url(pics/input.png); background-repeat : repeat-x;
  background-position: top left;
}
select {
  font-size:11px;
}
table.sql {
  background-color: #DDEEDD;
}
table.viewProp { 
  background-color: #DDEEDD;
}
td.viewPropTitle {
	background: #7FC08F;
  border: 1px solid #FAFFFA;
}
td.viewProp {
	background: #DDEEDD;
  border: 1px solid #FAFFFA;
}
table.Tip {
	background: #DDEEDD;
	border:1px solid gray;
 	filter:progid:DXImageTransform.Microsoft.Shadow(color=#BDC3BD, Direction=135, Strength=2); 
}
th.TipTitle {
 	font-size : 11px;
	background-image: url(pics/bg_title.png); background-repeat: repeat-x;
	background-color:#9CEBAE; 	
}
td.TipBody {
 	font-size : 10px;
}
.proptitle { border-left: 1px solid #BFEFDF; border-bottom: 1px solid #505550; border-right: 1px solid #446644; font-weight: bold; padding: 3; background: #7FC08F; color:#2F4F3F; background-image: url(pics/bg_title.png); background-repeat: repeat-x;}
td.proptitle { padding-left: 5; padding-right: 5;}

.viewProptitle { font-weight: bold;}
.viewProp { font-weight: bold;  }

a.Browse { color: DarkRed; font-weight: bold; font-weight: bold; text-decoration: none; }
a.Browse:hover { color: red; text-decoration: none; }

a {color: #446644; text-decoration: none; }
a:hover { color: #7FC08F; text-decoration: underline; }
a.base { font-size: 12px; color: #446644; font-weight: bold;  text-decoration: none; }
a.base:hover { color: #7FC08F; font-weight: bold;  text-decoration: none; }
a.titleHeader { font-size: 12px; font-family: Verdana, Arial, Helvetica, geneva, sans-serif;  color: #2F4F3F; font-weight: bold; text-decoration: none; }
a.titleHeader:hover { color: #2F4F3F; font-weight: bold; text-decoration: underline; }
a.propItemTitle { color: #446644; font-size: 12px; text-decoration: none; }
a.propItemTitle:hover { color: #7FC08F; text-decoration: none; }
a.propItem { color: #7FC08F; text-decoration: none; }
a.propItem:hover { color: #7FC08F; text-decoration: underline; }
a.PrivUser { color: red; font-weight: bold; text-decoration: none; }
a.PrivUser:hover { color: red; font-weight: bold; text-decoration: underline; }
a.PrivGroupe { color: red; font-weight: bold; text-decoration: none; }
a.PrivGroupe:hover { color: red; text-decoration: underline; }
.tabprop {font-size: 11px;}
.showSQL { decoration: none;}
.Index { border-left: 1px solid #DFE7DF; border-bottom: 1px solid #505550; border-right: 1px solid #556655; font-family: verdana,arial, helvetica, geneva, sans-serif; padding-left: 3px; padding-right: 3px;}
.insert { border-left: 1px solid #DFE7DF; border-bottom: 1px solid #505550; border-right: 1px solid #556655; font-family: verdana,arial, helvetica, geneva, sans-serif; padding-left: 3px;}
.small-input {font-size: 11px}
.export {font-weight: bold;}
legend{font-weight: bold;}
