body {
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 9pt;
	margin : 5 5 5 5;
	filter:progid:dximagetransform.microsoft.gradient(gradienttype=0,startcolorstr=#D7D7D7,endcolorstr=#FCFBFF);
}

tr,td, table {
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 9pt;
	margin : 5 5 5 5;
}

hr {
	border : 1px inset #ffffff;
}

.error {
	color: #ff0000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 9pt;
}
.input_color {
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 8pt;
	width: 65px;
	border: 1px solid  #b2b2b2;
}
.input {
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 8pt;
	border: 1px solid  #b2b2b2;
}
.input_small {
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 8pt;
	width: 50px;
	border: 1px solid  #b2b2b2;
}
.bt {
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 8pt;
	font-weight: bold;
	border : 1px solid #b2b2b2;
	filter:progid:dximagetransform.microsoft.gradient(gradienttype=0,startcolorstr=#FCFCFC,endcolorstr=#CECECE);
}
.img_pick {
	width : 10px;
	height : 10px;
	border : 1px solid #ffffff;
}
.img_pick_over {
	width : 10px;
	height : 10px;
	border : 1px outset #ff0000;
}
.align_off {
	border : 2px outset #ffffff;
}
.align_on {
	border : 2px inset #ffffff;
}

