body, tr,td, table {
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 9pt;
}
.style1 {
	color: green;
	font-family: Verdana, Arial, Helvetica, sans-serif;
  font-weight : bolder;
	font-size: 10pt;
}
.style2 {
	color: red;
  background-color: #dddddd;
	font-family: Verdana, Arial, Helvetica, sans-serif;
  font-weight : bolder;
	font-size: 12pt;
}

