.SPAW_classic_toolbar {
	background-color : #D6D3CE;
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 9pt;
}
.SPAW_classic_toolbar_top, .SPAW_classic_toolbar_left {
	background-color : #D6D3CE;
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 9pt;
	padding-left : 5px;
	padding-right : 5px;
	padding-top : 1px;
	padding-bottom : 1px;
}
.SPAW_classic_toolbar_right, .SPAW_classic_toolbar_bottom {
	background-color : #D6D3CE;
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 9pt;
	padding-left : 1px;
	padding-right : 1px;
	padding-top : 5px;
	padding-bottom : 5px;
}
.SPAW_classic_tb_input {
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 8pt;
}
.SPAW_classic_tb_over {
	border-bottom : 1px solid #aaaaaa;
	border-right : 1px solid #aaaaaa;
	border-left : 1px solid #eeeeee;
	border-top : 1px solid #eeeeee;
}
.SPAW_classic_tb_out {
	border : 1px solid #D6D3CE;
}
.SPAW_classic_tb_down {
	background-color : #F6F3EE;
	border-top : 1px solid #aaaaaa;
	border-left : 1px solid #aaaaaa;
	border-right : 1px solid #eeeeee;
	border-bottom : 1px solid #eeeeee;
}

