body, tr,td, table {
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 9pt;
	margin : 5 5 5 5;
}
.error {
	color: #ff0000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 9pt;
}
.input_color {
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 8pt;
	width: 65px;
	border-left : 1px solid  #000000;
	border-right : 1px solid #000000;
	border-top : 1px solid #000000;
	border-bottom : 1px solid #000000;
}
.input {
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 8pt;
	border-left : 1px solid  #000000;
	border-right : 1px solid #000000;
	border-top : 1px solid #000000;
	border-bottom : 1px solid #000000;
}
.input_small {
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 8pt;
	width: 50px;
	border-left : 1px solid  #000000;
	border-right : 1px solid #000000;
	border-top : 1px solid #000000;
	border-bottom : 1px solid #000000;
}
.bt {
	color: #000000;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 8pt;
	border-left : 1px solid  #000000;
	border-right : 1px solid #000000;
	border-top : 1px solid #000000;
	border-bottom : 1px solid #000000;
}
.img_pick {
	width : 10px;
	height : 10px;
	border : 1px solid #ffffff;
}
.img_pick_over {
	width : 10px;
	height : 10px;
	border : 1px solid #ff0000;
}
.align_off {
	border : 2px solid #ffffff;
}
.align_on {
	border : 2px solid #ff0000;
}

