<?php
/**
* Web based SQLite management
* @package SQLiteManager
* @version $Id: brazilian_portuguese.inc.php,v 1.29 2006/04/14 19:14:42 freddy78 Exp $ $Revision: 1.29 $
*/
/*
 Translated by Maurício M. Maia <mauricio.maia@gmail.com>
 SQLite Brasil <http://sqlitebrasil.codigolivre.org.br>
 */
$charset = 'iso-8859-1';
$langSuffix = 'br';
/**
* Fichier d'internationnalisation
*/
$itemTranslated = array(	"Table"		=> "Tabela", 
							"View"		=> "Visão",
							"Trigger"	=> "Trigger",
							"Function"	=> "Função");

$langueTranslated = array(	1=>"Francês", 2=>"Inglês", 3=>"Polonês", 
							4=>"Alemão", 5=>"Japonês", 6=>"Italiano", 
							7=>"Croata", 8=>"Português brasileiro", 9=>"Holandês", 
							10=>"Espanhol", 11=>"Dinamarquês", 12=>"Chinês traditional", 
              				13=>"Chinês simplificado");

$themeTranslated = array("default"=>"Padrão",  "PMA"=>"PMA", "jall"=>"JALL", "green"=>"Green");

$TEXT[1]	=	"Início";
$TEXT[2]	=	"Bem Vindo ao <a href=\"http://www.sqlitemanager.org\" target=\"_blank\">SQLiteManager</a> versão";
$TEXT[3]	=	"SQLite versão";
$TEXT[4]	=	"Documentação SQLite";
$TEXT[5]	=	"Linguaguem SQL";
$TEXT[6]	=	"A extensão SQLite não pode ser carregada.";
$TEXT[7]	=	"Não foi possível abrir o banco de dados de configuração 'SQLite' .<br>Menssegem de erro";
$TEXT[8]	=	"O banco de dados de configuração não tem permissão de escrita!";
$TEXT[9]	=	"Erro";
$TEXT[10]	=	"Função";
$TEXT[11]	=	"Aggregate";
$TEXT[12]	=	"Final function";
$TEXT[13]	=	"Nº Args";
$TEXT[14]	=	"Modificar";
$TEXT[15]	=	"Excluir";
$TEXT[16]	=	"Propriedades da nova Função";
$TEXT[17]	=	"Propriedades da Função";
$TEXT[18]	=	"Erro : Todos os campos devem ser preenchidos.";
$TEXT[19]	=	"Nome";
$TEXT[20]	=	"Tipo";
$TEXT[21]	=	"Step Properties";
$TEXT[22]	=	"Final Properties";
$TEXT[23]	=	"Nº args";
$TEXT[24]	=	"Atribuir esta função a todos os bancos de dados.";
$TEXT[25]	=	"Propriedades da nova Tabela";
$TEXT[26]	=	"Propriedades da Tabela";
$TEXT[27]	=	"Campo";
$TEXT[28]	=	"Tipo";
$TEXT[29]	=	"Comprimento";
$TEXT[30]	=	"Nulo";
$TEXT[31]	=	"Padrão";
$TEXT[32]	=	"Primária";
$TEXT[33]	=	"Ação";
$TEXT[34]	=	"Marcar todos";
$TEXT[35]	=	"Desmarcar todos";
$TEXT[36]	=	"Para os selecionados";
$TEXT[37]	=	"Você tem certeza que quer excluir este(s) campos?";
$TEXT[38]	=	"Gerenciamento de índice(s)";
$TEXT[39]	=	"Você tem certeza que quer excluir este campo";
$TEXT[40]	=	"Sim";
$TEXT[41]	=	"Não";
$TEXT[42]	=	"Primária";
$TEXT[43]	=	"Adicionar";
$TEXT[44]	=	"Campo(s)";
$TEXT[45]	=	"No fim da tabela";
$TEXT[46]	=	"No início da tabela";
$TEXT[47]	=	"Depois";
$TEXT[48]	=	"Inserir novo registro";
$TEXT[49]	=	"Modificar um registro";
$TEXT[50]	=	"Valor";
$TEXT[51]	=	"Salvar";
$TEXT[52]	=	"Inserir dados de um arquivo.";
$TEXT[53]	=	"Trigger";
$TEXT[54]	=	"Propriedades do novo Trigger";
$TEXT[55]	=	"Propriedades do Trigger";
$TEXT[56]	=	"Momento";
$TEXT[57]	=	"Evento";
$TEXT[58]	=	"On";
$TEXT[59]	=	"Condição";
$TEXT[60]	=	"Passo";
$TEXT[61]	=	"Propriedades";
$TEXT[62]	=	"Propriedades da nova Visão";
$TEXT[63]	=	"Propriedades da Visão";
$TEXT[64]	=	"Nenhuma instrução foi executada!";
$TEXT[65]	=	"Bad resource connection!";
$TEXT[66]	=	"Execute uma ou mais <b>instruções(s)";
$TEXT[67]	=	"<i>Ou</i> de um arquivo sql";
$TEXT[68]	=	"Formato da instrução : Padrão (sqlite)";
$TEXT[69]	=	"Executar";
$TEXT[70]	=	"instrução foi executada.";
$TEXT[71]	=	"Registro foi modificado.";
$TEXT[72]	=	"Estrutura";
$TEXT[73]	=	"Exibir";
$TEXT[74]	=	"SQL";
$TEXT[75]	=	"Inserir";
$TEXT[76]	=	"Exportar";
$TEXT[77]	=	"Esvaziar";
$TEXT[78]	=	"Você realmente deseja excluir esta função?";
$TEXT[79]	=	"Você realmente deseja esvaziar esta tabela?";
$TEXT[80]	=	"Você realmente deseja excluir esta tabela?";
$TEXT[81]	=	"Adicionar";
$TEXT[82]	=	"Você realmente deseja excluir esta visão?";
$TEXT[83]	=	"Você realmente deseja excluir este trigger?";
$TEXT[84]	=	"Opções";
$TEXT[85]	=	"Você está realmente certo que deseja excluir este banco de dados? Isto é apenas uma desassociação, o banco de dados não é destruído.  ";
$TEXT[86]	=	"Excluir";
$TEXT[87]	=	"Adicionar uma Visão";
$TEXT[88]	=	"Adicionar um Trigger";
$TEXT[89]	=	"Adicionar uma Função";
$TEXT[90]	=	"Instrução SQL";
$TEXT[91]	=	"Nome da chave";
$TEXT[92]	=	"Você realmente deseja excluir este Índice";
$TEXT[93]	=	"Adicionar um Índice em";
$TEXT[94]	=	"coluna(s)";
$TEXT[95]	=	"Ignorar";
$TEXT[96]	=	"Adicionar na chave";
$TEXT[97]	=	"Criar uma Visão com nome ";
$TEXT[98]	=	"desta instrução.";
$TEXT[99]	=	"Linha(s) de erro";
$TEXT[100]	=	"Certamente há um problema de permissão de escrita no banco de dados de configuração";
$TEXT[101]	=	"Impossível criar ou ler banco de dados";
$TEXT[102]	=	"Todos os campos precisam ser preenchidos!";
$TEXT[103]	=	"Adicionar banco de dados";
$TEXT[104]	=	"Caminho";
$TEXT[105]	=	"O array de dados não tem um número constate de elementos";
$TEXT[106]	=	"Os parâmetros do construtor da classe 'Grid' devem ser um array";
$TEXT[107]	=	"O array de alinhamento de coluna não tem um bom número de elementos.";
$TEXT[108]	=	"O alinhamento das células devem ser: 'left', 'right' ou 'center'";
$TEXT[109]	=	"Os parâmetros para o alinhamento das colunas devem ser um array";
$TEXT[110]	=	"Os parâmetros para o formato das colunas devem ser um array array";
$TEXT[111]	=	"O array de ordenação da coluna não tem um bom número de elementos.";
$TEXT[112]	=	"Os parâmetros de ordenação devem ser 0=não ordenar, Ou 1=ordenar.";
$TEXT[113]	=	"Os parâmetros para ordenação das colunas devem ser um array";
$TEXT[114]	=	"The format string for the calculate column is empty.";
$TEXT[115]	=	"O título é obrigatório para um campo calculado.";
$TEXT[116]	=	"Os parâmetros para o construtor da classe 'ArrayToGrid' devem ser um array.";
$TEXT[117]	=	"Impossível contar o número de registros";
$TEXT[118]	=	"Nº registros";
$TEXT[119]	=	"Inserir";
$TEXT[120]	=	"Você tem certeza que deseja excluir";
$TEXT[121]	=	"o";
$TEXT[122]	=	"a";
$TEXT[123]	=	"Você tem certeza que deseja esvaziar esta tabela";
$TEXT[124]	=	"Estrutura apenas";
$TEXT[125]	=	"Estrutura e Dados";
$TEXT[126]	=	"Dados apenas";
$TEXT[127]	=	"Inserts completos";
$TEXT[128]	=	"enviar";
$TEXT[129]	=	"Host";
$TEXT[130]	=	"Hora da Geração";
$TEXT[131]	=	"Banco de Dados";
$TEXT[132]	=	"Estrutura da tabela para a tabela";
$TEXT[133]	=	"Descarregando dados para a tabela";
$TEXT[134]	=	"Estrutura da visualização para a visão";
$TEXT[135]	=	"Propriedades das Funções Definidas pelo Usuário";
$TEXT[136]	=	"Registros";
$TEXT[137]	=	"Arquivo";
$TEXT[138]	=	"Substituir conteúdo";
$TEXT[139]	=	"Separador";
$TEXT[140]	=	"Inserir dados de arquivo texto formatado";
$TEXT[141]	=	"Idioma";
$TEXT[142]	=	"Tema";
$TEXT[143]	=	"Upload Banco de Dados";
$TEXT[144]	=	"Diretório de upload não está acessível.<br>(Modifique a constante 'DEFAULT_DB_PATH' no arquivo 'include/user_defined.inc.php')";
$TEXT[145]	=	"Explain SQL";
$TEXT[146]	=	"Gerenciamento de bancos de dados anexos";
$TEXT[147]	=	"Você não está autorizado a acessar aqui. Você deve fornecer um usuário e senha válidos.";
$TEXT[148]	=	"Este usuário não é válido.";
$TEXT[149]	=	"Esta senha não corresponde com o usuário.";
$TEXT[150]	=	"PHP versão";
$TEXT[151] = 	"Depois de salvar";
$TEXT[152] = 	"Voltar para a página anterior";
$TEXT[153] = 	"Inserir outro registro";
$TEXT[154] = 	"O banco de dados de configuração está em somente leitura.<br>Alguns recursos do SQLiteManager não podem funcionar corretamente.";
$TEXT[155] = 	"Este banco de dados está em somente leitura.";
$TEXT[156] = 	"Privilégios"; 
$TEXT[157] = 	"Mudar senha"; 
$TEXT[158] = 	"Sair"; 
$TEXT[159] = 	"Adicionar usuário"; 
$TEXT[160] = 	"Adicionar grupo"; 
$TEXT[161] = 	"User overview"; 
$TEXT[162] = 	"Groupes overview"; 
$TEXT[163] = 	"Nome"; 
$TEXT[164] = 	"Usuário"; 
$TEXT[165] = 	"Grupo"; 
$TEXT[166] = 	"execSQL"; 
$TEXT[167] = 	"dado"; 
$TEXT[168] = 	"exportar"; 
$TEXT[169] = 	"esvaziar"; 
$TEXT[170] = 	"del"; 
$TEXT[171] = 	"Senha antiga incorreta."; 
$TEXT[172] = 	"Senha e confirmação são diferentes."; 
$TEXT[173] = 	"A senha foi mudada"; 
$TEXT[174] = 	"Clique aqui para entrar novamente"; 
$TEXT[175] = 	"Antiga :"; 
$TEXT[176] = 	"Nova :"; 
$TEXT[177] = 	"Confirme :"; 
$TEXT[178] = 	"Informação"; 
$TEXT[179] = 	"Localização :"; 
$TEXT[180] = 	"Tamanho :"; 
$TEXT[181] = 	"Privilégios :"; 
$TEXT[182] = 	"Última modificação :"; 
$TEXT[183] = 	"Integrity Check"; 
$TEXT[184] = 	"Vacuum"; 
$TEXT[185] = 	"Default synchronous :"; 
$TEXT[186] = 	"Default cache_size :"; 
$TEXT[187] = 	"OFF "; 
$TEXT[188] = 	"NORMAL "; 
$TEXT[189] = 	"FULL "; 
$TEXT[190]	= 	"Gerenciamento de controle de acesso"; 
$TEXT[191]	= 	"sim"; 
$TEXT[192]	= 	"não"; 
$TEXT[193]	= 	"Default Temporary Storage"; 
$TEXT[194]	= 	"DEFAULT"; 
$TEXT[195]	= 	"MEMORY"; 
$TEXT[196]	= 	"FILE"; 
$TEXT[197]	= 	"Único"; 
$TEXT[198]	= 	"Índice"; 
$TEXT[199]	= 	"Dados";
$TEXT[200]	= 	"Aplicar";
$TEXT[201]	=	"Selecionar";
$TEXT[202]	=	"Operador";
$TEXT[203]	=	"condição adicional :";
$TEXT[204]	=	"AND";
$TEXT[205]	=	"OR";
$TEXT[206]	=	"Selecionar";
$TEXT[207]	=	"Buscar";
$TEXT[208]	=	"Renomear";
$TEXT[209]	=	"Mover";
$TEXT[210]	=	"Copiar";
$TEXT[211]	=	"Plugins";
$TEXT[212]	=	"Manutenção";
$TEXT[213]	=	"Tempo execução :";
$TEXT[214]	=	"msec.";
$TEXT[215]	=	"Renomear tabela para :";
$TEXT[216]	=	"Mover tabela para (database.table) :";
$TEXT[217]	=	"Copiar tabela para (database.table) :";
$TEXT[218]	=	"Adicionar DROP TABLE";
$TEXT[219]	=	"Salavar como Novo Registro";
$TEXT[220]	=	"Salvar";
$TEXT[221]	=	"Salvar Tipo";
$TEXT[222]  =   "Operação";
$TEXT[223]  =   "Atualizar";
$TEXT[224]  =   "Dica : Você pode usar funções PHP em suas instruções !";
$TEXT[225]  =   "Texto truncado";
$TEXT[226]  =   "Texto completo";
$TEXT[227]  =   "-- select --";
$TEXT[228]  =   "(s)";
$TEXT[229]  =   "Version";
$TEXT[230]  =   "(new database)";
$TEXT[231]  =   "Official SQliteManager Homepage";
$TEXT[232]  =   "The database can't be attain";
$TEXT[233]  =   "Trigger structure";
?>
