<?php
/**
* Web based SQLite management
* @package SQLiteManager
* @version $Id: traditional_chinese.inc.php,v 1.2 2006/04/14 15:16:52 freddy78 Exp $ $Revision: 1.2 $
* @version $Id: traditional_chinese.inc.php,v 1.2 2006/04/14 15:16:52 freddy78 Exp $Revision: 1.2 $
*/
$charset = 'Big5';
$langSuffix = 'sz';
/**
* Fichier d'internationnalisation
*/
$itemTranslated = array(	"Table"		=> "表格", 
							"View"		=> "視圖",
							"Trigger"	=> "觸發器",
							"Function"	=> "函數");

$langueTranslated = array(	1=>"法語", 2=>"英語", 3=>"波蘭語", 
							4=>"德語", 5=>"倭語", 6=>"義大利語", 
							7=>"克羅地亞語", 8=>"巴西葡萄牙語", 9=>"荷蘭語", 
							10=>"西班牙語", 11=>"丹麥語",12=>"簡體中文",13=>"繁體中文");

$themeTranslated = array("default"=>"默認", "green"=>"綠色", "PMA"=>"PMA", "jall"=>"Jall");

$TEXT[1]	=	"主頁";
$TEXT[2]	=	"歡迎使用<a href=\"http://www.sqlitemanager.org\" target=\"_blank\">SQLiteManager</a> 版本";
$TEXT[3]	=	"SQLite版本";
$TEXT[4]	=	"SQLite文檔";
$TEXT[5]	=	"SQL語言";
$TEXT[6]	=	"SQLite擴展沒有載入.";
$TEXT[7]	=	"打不開'SQLite'配置資料庫.<br>錯誤消息";
$TEXT[8]	=	"配置資料庫沒有'寫'許可權!";
$TEXT[9]	=	"錯誤";
$TEXT[10]	=	"函數";
$TEXT[11]	=	"聚合";
$TEXT[12]	=	"Final function";
$TEXT[13]	=	"Nb Args";
$TEXT[14]	=	"修改";
$TEXT[15]	=	"刪除";
$TEXT[16]	=	"新函數屬性";
$TEXT[17]	=	"函數屬性";
$TEXT[18]	=	"錯誤: 必有欄位都有必須填入值.";
$TEXT[19]	=	"名稱";
$TEXT[20]	=	"類型";
$TEXT[21]	=	"步驟屬性";
$TEXT[22]	=	"最後屬性";
$TEXT[23]	=	"Nb 參數";
$TEXT[24]	=	"將此函數應用到所有資料庫.";
$TEXT[25]	=	"新建表屬性";
$TEXT[26]	=	"表格屬性";
$TEXT[27]	=	"欄位";
$TEXT[28]	=	"類型";
$TEXT[29]	=	"長度";
$TEXT[30]	=	"空值";
$TEXT[31]	=	"預設值";
$TEXT[32]	=	"主鍵";
$TEXT[33]	=	"動作";
$TEXT[34]	=	"全選";
$TEXT[35]	=	"全不選";
$TEXT[36]	=	"為選擇集";
$TEXT[37]	=	"你確定要刪除掉這個/這些欄位嗎?";
$TEXT[38]	=	"管理索引(s)";
$TEXT[39]	=	"你確實想刪除這個欄位嗎?";
$TEXT[40]	=	"是的";
$TEXT[41]	=	"不是";
$TEXT[42]	=	"主鍵";
$TEXT[43]	=	"添加";
$TEXT[44]	=	"欄位(s)";
$TEXT[45]	=	"在表格的最後";
$TEXT[46]	=	"在表格的開頭";
$TEXT[47]	=	"在下面欄位之後:";
$TEXT[48]	=	"插入新記錄";
$TEXT[49]	=	"修改一條記錄";
$TEXT[50]	=	"值";
$TEXT[51]	=	"保存";
$TEXT[52]	=	"從檔中載入資料.";
$TEXT[53]	=	"觸發器";
$TEXT[54]	=	"新建觸發器屬性";
$TEXT[55]	=	"觸發器屬性";
$TEXT[56]	=	"時刻";
$TEXT[57]	=	"事件";
$TEXT[58]	=	"在";
$TEXT[59]	=	"條件";
$TEXT[60]	=	"步驟";
$TEXT[61]	=	"屬性";
$TEXT[62]	=	"新建視圖屬性";
$TEXT[63]	=	"視圖屬性";
$TEXT[64]	=	"沒有執行任何查詢!";
$TEXT[65]	=	"錯誤的資源鏈結!";
$TEXT[66]	=	"執行一個或多個 <b>請求(s)";
$TEXT[67]	=	"<i>或</i>自一個SQL檔";
$TEXT[68]	=	"查詢格式 : 標準 (SQLite)";
$TEXT[69]	=	"執行";
$TEXT[70]	=	"查詢已被執行.";
$TEXT[71]	=	"查詢修改了行.";
$TEXT[72]	=	"結構";
$TEXT[73]	=	"顯示";
$TEXT[74]	=	"SQL";
$TEXT[75]	=	"插入";
$TEXT[76]	=	"導出";
$TEXT[77]	=	"清空";
$TEXT[78]	=	"你真的想刪除這個函數嗎?";
$TEXT[79]	=	"你真的想清空這個表格嗎?";
$TEXT[80]	=	"你真的想刪除這個表格嗎?";
$TEXT[81]	=	"添加";
$TEXT[82]	=	"你真的想刪除這個視圖嗎?";
$TEXT[83]	=	"你真的想刪除這個觸發器嗎?";
$TEXT[84]	=	"選項";
$TEXT[85]	=	"你真的確定要刪除這個資料庫嗎? 這個刪除操作只是斷開SQLiteManager與資料庫的連接,資料庫本身不會被刪除.  ";
$TEXT[86]	=	"刪除";
$TEXT[87]	=	"添加一個新的視圖";
$TEXT[88]	=	"添加一個新的觸發器";
$TEXT[89]	=	"添加一個新的函數";
$TEXT[90]	=	"SQL查詢";
$TEXT[91]	=	"鍵名";
$TEXT[92]	=	"你真的想刪除這個索引嗎?";
$TEXT[93]	=	"添加一個索引在";
$TEXT[94]	=	"列(s)";
$TEXT[95]	=	"忽視";
$TEXT[96]	=	"添加鍵";
$TEXT[97]	=	"新建一個視圖並命名為";
$TEXT[98]	=	"從這個查詢.";
$TEXT[99]	=	"錯誤行(s)";
$TEXT[100]	=	"肯定是由於配置資訊資料庫存在一個寫許可權的問題";
$TEXT[101]	=	"不能創建或讀取這個資料庫";
$TEXT[102]	=	"所有項都必須填入內容!";
$TEXT[103]	=	"創建或添加新資料庫";
$TEXT[104]	=	"路徑";
$TEXT[105]	=	"資料陣列沒有常量數位元素";
$TEXT[106]	=	"構造類'Grid'的參數必須是一個陣列";
$TEXT[107]	=	"列排列陣列不是沒有合適的元素.(原文可能有誤)";
$TEXT[108]	=	"單格排列串必須是 : 'left', 'right' 或者 'center'";
$TEXT[109]	=	"列排列的參數必須是陣列";
$TEXT[110]	=	"列格式的參數必須是陣列";
$TEXT[111]	=	"列排序陣列不是沒有合適的元素.(原文可能有誤)";
$TEXT[112]	=	"排序陣列必須是 0=不排序, 或者是 1=排序.";
$TEXT[113]	=	"列排序的參數必須是一個陣列";
$TEXT[114]	=	"計算列的格式字串是空的.";
$TEXT[115]	=	"計算列的標題是必須的.";
$TEXT[116]	=	"構造類'ArrayToGrid' 的參數必須是一個陣列.";
$TEXT[117]	=	"無法獲得記錄數";
$TEXT[118]	=	"Nb 記錄";
$TEXT[119]	=	"插入";
$TEXT[120]	=	"你確定要刪除";
$TEXT[121]	=	"此";
$TEXT[122]	=	"此";
$TEXT[123]	=	"你確定要清空這個表格嗎?";
$TEXT[124]	=	"僅需結構";
$TEXT[125]	=	"結構和資料";
$TEXT[126]	=	"僅需數據";
$TEXT[127]	=	"完全插入格式";
$TEXT[128]	=	"發送";
$TEXT[129]	=	"主機";
$TEXT[130]	=	"生成時間";
$TEXT[131]	=	"資料庫";
$TEXT[132]	=	"表格的表格結構";
$TEXT[133]	=	"從表格中導出資料";
$TEXT[134]	=	"視圖的視圖的結構";
$TEXT[135]	=	"用戶自定義函數屬性";
$TEXT[136]	=	"記錄";
$TEXT[137]	=	"文件";
$TEXT[138]	=	"內容替換";
$TEXT[139]	=	"分格符";
$TEXT[140]	=	"從文本格式的檔來載入插入資料";
$TEXT[141]	=	"語言";
$TEXT[142]	=	"頁面風格";
$TEXT[143]	=	"上傳資料庫";
$TEXT[144]	=	"上傳目錄不可訪問.<br>(修改檔 'include/user_defined.inc.php'中的 'DEFAULT_DB_PATH'常量)";
$TEXT[145]	=	"解析SQL";
$TEXT[146]	=	"管理附屬資料庫";
$TEXT[147]	=	"此地你沒有許可權訪問.你的登錄名和密碼不對.";
$TEXT[148]	=	"登錄失敗.";
$TEXT[149]	=	"該登錄的登錄名的密碼不對.";
$TEXT[150]	=	"PHP版本";
$TEXT[151]	= 	"保存之後";
$TEXT[152]	= 	"返回前一頁";
$TEXT[153]	= 	"添加另外新的一行";
$TEXT[154]	= 	"配置資料庫唯讀.<br> SQLiteManager 的某些功能可能不能正常運行.";
$TEXT[155]	= 	"資料庫唯讀.";
$TEXT[156]	= 	"許可權"; 
$TEXT[157]	= 	"改變密碼"; 
$TEXT[158]	= 	"登出"; 
$TEXT[159]	= 	"添加用哀慟"; 
$TEXT[160]	= 	"添加分組"; 
$TEXT[161]	= 	"查看用戶"; 
$TEXT[162]	= 	"查看分組"; 
$TEXT[163]	= 	"名稱"; 
$TEXT[164]	= 	"登錄"; 
$TEXT[165]	= 	"分組"; 
$TEXT[166]	= 	"執行SQL"; 
$TEXT[167]	= 	"數據"; 
$TEXT[168]	= 	"導出"; 
$TEXT[169]	= 	"清空"; 
$TEXT[170]	= 	"刪除"; 
$TEXT[171]	= 	"舊密碼不對."; 
$TEXT[172]	= 	"密碼與其確認不同."; 
$TEXT[173]	= 	"密碼已修改"; 
$TEXT[174]	= 	"點擊這裏重新登錄"; 
$TEXT[175]	= 	"舊的 :"; 
$TEXT[176]	= 	"新的 :"; 
$TEXT[177]	= 	"確認 :"; 
$TEXT[178]	= 	"信息"; 
$TEXT[179]	= 	"位置 :"; 
$TEXT[180]	= 	"大小 :"; 
$TEXT[181]	= 	"許可權 :"; 
$TEXT[182]	= 	"最後修改 :"; 
$TEXT[183]	= 	"完整性檢查"; 
$TEXT[184]	= 	"緊縮"; 
$TEXT[185]	= 	"默認同步 :"; 
$TEXT[186]	= 	"默認緩衝區大小:"; 
$TEXT[187]	= 	"關閉 "; 
$TEXT[188]	= 	"正常 "; 
$TEXT[189]	= 	"全部 "; 
$TEXT[190]	= 	"訪問控制管理"; 
$TEXT[191]	= 	"是"; 
$TEXT[192]	= 	"否"; 
$TEXT[193]	= 	"默認臨時存儲"; 
$TEXT[194]	= 	"默認"; 
$TEXT[195]	= 	"記憶體"; 
$TEXT[196]	= 	"文件"; 
$TEXT[197]	= 	"唯一"; 
$TEXT[198]	= 	"索引"; 
$TEXT[199]	= 	"數據"; 
$TEXT[200]	= 	"應用";
$TEXT[201]	=	"選擇";
$TEXT[202]	=	"操作符";
$TEXT[203]	=	"符加條件 :";
$TEXT[204]	=	"並且";
$TEXT[205]	=	"或者";
$TEXT[206]	=	"選擇";
$TEXT[207]	=	"查詢";
$TEXT[208]	=	"重命名";
$TEXT[209]	=	"移動";
$TEXT[210]	=	"複製";
$TEXT[211]	=	"插件";
$TEXT[212]	=	"維護";
$TEXT[213]	=	"查詢時間 :";
$TEXT[214]	=	"毫秒.";
$TEXT[215]	=	"重命名到 :";
$TEXT[216]	=	"移動到(資料庫.表) :";
$TEXT[217]	=	"複製到 (資料庫.表) :";
$TEXT[218]	=	"添加刪除表";
$TEXT[219]	=	"另存為新行";
$TEXT[220]	=	"保存";
$TEXT[221]	=	"保存類型";
$TEXT[222]  =   "操作";
$TEXT[223]  =   "更新";
$TEXT[224]  =   "提示:您可以在你的查詢中使用PHP內部函數！";
$TEXT[225]  =   "截斷文本";
$TEXT[226]  =   "全文";
$TEXT[227]  =   "-- 請選擇 --";
$TEXT[228]  =   "(s)";
$TEXT[229]  =   "Version";
$TEXT[230]  =   "(new database)";
$TEXT[231]  =   "Official SQliteManager Homepage";
$TEXT[232]  =   "The database can't be attain";
$TEXT[233]  =   "Trigger structure";
?>