<?php
/**
* Web based SQLite management
* @package SQLiteManager
* @version $Id: spanish.inc.php,v 1.24 2006/04/14 15:16:52 freddy78 Exp $ $Revision: 1.24 $
*/
$charset = 'iso-8859-1';
$langSuffix = 'ca';
/**
* Fichier d'internationnalisation
*/
$itemTranslated = array(	"Table"		=> "Tabla",
							"View"		=> "Vista",
							"Trigger"	=> "Disparador",
							"Function"	=> "Función");

$langueTranslated = array(	1=>"Francés", 2=>"Inglés", 3=>"Polaco",
							4=>"Alemán", 5=>"Japonés", 6=>"Italiano",
							7=>"Croata", 8=>"Portugués", 9=>"Netherlands", 
							10=>"Español", 11=>"Danés", 12=>"Chinese traditional", 
              				13=>"Chinese simplified");

$themeTranslated = array("default"=>"Default",  "PMA"=>"PMA", "jall"=>"JALL", "green"=>"Green");

$TEXT[1]	=	"Principal";
$TEXT[2]	=	"Bienvenido a <a href=\"http://www.sqlitemanager.org\" target=\"_blank\">SQLiteManager</a> versión";
$TEXT[3]	=	"Versión SQLite";
$TEXT[4]	=	"Documentación SQLite";
$TEXT[5]	=	"Lenguaje SQL";
$TEXT[6]	=	"No se pudo cargar la extensión SQLite.";
$TEXT[7]	=	"No se pudo abrir la base de datos de configuración de 'SQLite'.<br>Mensaje de error";
$TEXT[8]	=	"¡La configuración de la base de datos no tiene derechos de 'Escritura'!";
$TEXT[9]	=	"Error";
$TEXT[10]	=	"Función";
$TEXT[11]	=	"Agregado";
$TEXT[12]	=	"Función final";
$TEXT[13]	=	"Nº Args";
$TEXT[14]	=	"Modificar";
$TEXT[15]	=	"Borrar";
$TEXT[16]	=	"Propiedades de nueva función";
$TEXT[17]	=	"Propiedades de función";
$TEXT[18]	=	"Error : Se deben rellenar todos los campos.";
$TEXT[19]	=	"Nombre";
$TEXT[20]	=	"Tipo";
$TEXT[21]	=	"Propiedades de Paso";
$TEXT[22]	=	"Propiedades Finales";
$TEXT[23]	=	"Nº Args";
$TEXT[24]	=	"Atribuir esta función a todas las bases de datos.";
$TEXT[25]	=	"Propiedades de tabla nueva";
$TEXT[26]	=	"Propiedades de tabla";
$TEXT[27]	=	"Campo";
$TEXT[28]	=	"Tipo";
$TEXT[29]	=	"Longitud";
$TEXT[30]	=	"Nulo";
$TEXT[31]	=	"Defecto";
$TEXT[32]	=	"Primaria";
$TEXT[33]	=	"Acción";
$TEXT[34]	=	"Seleccionar todas";
$TEXT[35]	=	"Deseleccionar todas";
$TEXT[36]	=	"Para la selección";
$TEXT[37]	=	"¿Estás seguro que quieres borrar este/os campo/s?";
$TEXT[38]	=	"Administración de índice(s)";
$TEXT[39]	=	"¿Borrar el campo seleccionado?";
$TEXT[40]	=	"Sí";
$TEXT[41]	=	"No";
$TEXT[42]	=	"Primario";
$TEXT[43]	=	"Añadir";
$TEXT[44]	=	"Campo(s)";
$TEXT[45]	=	"Al final de la tabla";
$TEXT[46]	=	"Al comienzo de la tabla";
$TEXT[47]	=	"Detrás";
$TEXT[48]	=	"Insertar fila nueva";
$TEXT[49]	=	"Modificar fila";
$TEXT[50]	=	"Valor";
$TEXT[51]	=	"Guardar";
$TEXT[52]	=	"Insertar datos desde un fichero.";
$TEXT[53]	=	"Disparador";
$TEXT[54]	=	"Propiedades de nuevo disparador";
$TEXT[55]	=	"Propiedades de disparador";
$TEXT[56]	=	"Moment";
$TEXT[57]	=	"Evento";
$TEXT[58]	=	"En";
$TEXT[59]	=	"Condición";
$TEXT[60]	=	"Paso";
$TEXT[61]	=	"Propiedades";
$TEXT[62]	=	"Propiedades de nueva vista";
$TEXT[63]	=	"Propiedades de vista";
$TEXT[64]	=	"¡No se ha ejecutado ninguna query!";
$TEXT[65]	=	"¡Recurso de conexión erróneo!";
$TEXT[66]	=	"Ejecutar una o mas <b>petición(es)";
$TEXT[67]	=	"<i>O</i> desde un fichero sql";
$TEXT[68]	=	"Formato de Query : Estándar (sqlite)";
$TEXT[69]	=	"Ejecutar";
$TEXT[70]	=	"la query ha sido ejecutada.";
$TEXT[71]	=	"La línea ha sido modificada.";
$TEXT[72]	=	"Estructura";
$TEXT[73]	=	"Examinar";
$TEXT[74]	=	"SQL";
$TEXT[75]	=	"Insertar";
$TEXT[76]	=	"Exportar";
$TEXT[77]	=	"Vaciar";
$TEXT[78]	=	"¿Borrar función?";
$TEXT[79]	=	"¿Vaciar tabla?";
$TEXT[80]	=	"¿Borrar tabla?";
$TEXT[81]	=	"Añadir";
$TEXT[82]	=	"¿Borrar vista?";
$TEXT[83]	=	"¿Borrar disparador?";
$TEXT[84]	=	"Opciones";
$TEXT[85]	=	"¿Borrar base de datos? Sólo se eliminará la suscripción, el fichero de base de datos no se borrará.";
$TEXT[86]	=	"Borrar";
$TEXT[87]	=	"Añadir nueva Vista";
$TEXT[88]	=	"Añadir nuevo Disparador";
$TEXT[89]	=	"Añadir nueva función";
$TEXT[90]	=	"query SQL";
$TEXT[91]	=	"Nombre de Clave";
$TEXT[92]	=	"¿Borrar Índice?";
$TEXT[93]	=	"Añadir un Índice en";
$TEXT[94]	=	"columna(s)";
$TEXT[95]	=	"Ignorar";
$TEXT[96]	=	"Añadir en la clave";
$TEXT[97]	=	"Crear una Vista con nombre ";
$TEXT[98]	=	"desde esta query.";
$TEXT[99]	=	"Error línea(s)";
$TEXT[100]	=	"Probablemente sea un problema de derechos de escritura de la configuración de la base de datos";
$TEXT[101]	=	"Imposible crear o leer esta base de datos";
$TEXT[102]	=	"¡Se deben rellenar todos los campos!";
$TEXT[103]	=	"Añadir nueva base de datos";
$TEXT[104]	=	"Dirección";
$TEXT[105]	=	"El array de datos no tiene un numero constante de elementos";
$TEXT[106]	=	"Los parámetros de la clase constructora 'Grid' deben ser arrays";
$TEXT[107]	=	"La array de alineación de columna no tiene un número correcto de elementos.";
$TEXT[108]	=	"La alineación de celdas debe ser : 'izquierda', 'derecha' o 'centro'";
$TEXT[109]	=	"Los parámetros para la alineación de columnas debe ser un array";
$TEXT[110]	=	"Los parámetros para el formato de columnas debe ser un array";
$TEXT[111]	=	"La array de orden de columnas no tiene un numero correcto de elementos.";
$TEXT[112]	=	"Los parámetros de orden deben ser 0=sin orden, O 1=ordenado.";
$TEXT[113]	=	"Los parámetros para el orden de columnas debe ser un array";
$TEXT[114]	=	"La cadena de formato para el cálculo de columna está vacío.";
$TEXT[115]	=	"El título es obligatorio para un cálculo de columnas.";
$TEXT[116]	=	"Los parámetros de la clase constructora 'ArrayToGrid' deben ser arrays.";
$TEXT[117]	=	"Imposible contar el número de filas";
$TEXT[118]	=	"Nº filas";
$TEXT[119]	=	"Añadir";
$TEXT[120]	=	"Seguro que desea borrar";
$TEXT[121]	=	"el";
$TEXT[122]	=	"la";
$TEXT[123]	=	"¿Vaciar tabla?";
$TEXT[124]	=	"Solo Estructura";
$TEXT[125]	=	"Estructura y Datos";
$TEXT[126]	=	"Solo Datos";
$TEXT[127]	=	"Completar inserts";
$TEXT[128]	=	"enviar";
$TEXT[129]	=	"Host";
$TEXT[130]	=	"Tiempo de Generación";
$TEXT[131]	=	"Base de datos";
$TEXT[132]	=	"Table structure for table";
$TEXT[133]	=	"Volgado de datos para la tabla";
$TEXT[134]	=	"Ver estructura para vista";
$TEXT[135]	=	"User Defined Function properties";
$TEXT[136]	=	"Filas";
$TEXT[137]	=	"Fichero";
$TEXT[138]	=	"Remplazar contenido";
$TEXT[139]	=	"Separador";
$TEXT[140]	=	"Inserción de datos desde un fichero de texto formateado";
$TEXT[141]	=	"Idioma";
$TEXT[142]	=	"Tema";
$TEXT[143]	=	"Subir Base de datos";
$TEXT[144]	=	"No se puede acceder al directorio de Subida.<br>(Modifica la constante 'DEFAULT_DB_PATH' en el fichero 'include/user_defined.inc.php')";
$TEXT[145]	=	"Explicar SQL";
$TEXT[146]	=	"Administración las bases de datos anexadas";
$TEXT[147]	=	"No tienes permiso para acceder aquí.Debes introducir un login y una contraseña válidos.";
$TEXT[148]	=	"Login incorrecto.";
$TEXT[149]	=	"La contraseña no corresponde con el login.";
$TEXT[150]	=	"Versión de PHP";
$TEXT[151] = 	"Despues de grabar";
$TEXT[152] = 	"Volver a la página anterior";
$TEXT[153] = 	"Insertar otra fila";
$TEXT[154] = 	"The configuration database is in read only.<br>Some feature of SQLiteManager can't work correctly.";
$TEXT[155] = 	"La base de datos es de solo escritura.";
$TEXT[156] = 	"Privilegios";
$TEXT[157] = 	"Cambiar contraseña";
$TEXT[158] = 	"Desconexión";
$TEXT[159] = 	"Añadir usuario";
$TEXT[160] = 	"Añadir grupo";
$TEXT[161] = 	"Vista de Usuarios";
$TEXT[162] = 	"Vista de Grupos";
$TEXT[163] = 	"Nombre";
$TEXT[164] = 	"Login";
$TEXT[165] = 	"Grupo";
$TEXT[166] = 	"execSQL";
$TEXT[167] = 	"data";
$TEXT[168] = 	"exportar";
$TEXT[169] = 	"vaciar";
$TEXT[170] = 	"borrar";
$TEXT[171] = 	"Contraseña Antigua incorrecta.";
$TEXT[172] = 	"La contraseña y la configuración son diferentes.";
$TEXT[173] = 	"La contraseña ha sido cambiada";
$TEXT[174] = 	"Click aquí para re-entrar";
$TEXT[175] = 	"Vieja :";
$TEXT[176] = 	"Nueva :";
$TEXT[177] = 	"Confirmación :";
$TEXT[178] = 	"Información";
$TEXT[179] = 	"Localización :";
$TEXT[180] = 	"Tamaño :";
$TEXT[181] = 	"Derechos :";
$TEXT[182] = 	"Última modificación :";
$TEXT[183] = 	"Comprobación de Integridad";
$TEXT[184] = 	"Limpiar";
$TEXT[185] = 	"Sincronización por Defecto :";
$TEXT[186] = 	"Tamaño de cache por defecto (cache_size) :";
$TEXT[187] = 	"APAGADO ";
$TEXT[188] = 	"NORMAL ";
$TEXT[189] = 	"COMPLETO ";
$TEXT[190]	= 	"Acceso al panel de control";
$TEXT[191]	= 	"Nombre";
$TEXT[192]	= 	"Login";
$TEXT[193]	= 	"";
$TEXT[194]	= 	"Sí";
$TEXT[195]	= 	"No";
$TEXT[193]	= 	"Almacenamiento Temporal por Defecto";
$TEXT[194]	= 	"DEFECTO";
$TEXT[195]	= 	"MEMÓRIA";
$TEXT[196]	= 	"FICHERO";
$TEXT[197]	= 	"Único";
$TEXT[198]	= 	"Índice";
$TEXT[197]	= 	"Único";
$TEXT[198]	= 	"Índice";
$TEXT[199]	= 	"Datos";
$TEXT[200]	= 	"Aplicar";
$TEXT[201]	=	"Selección";
$TEXT[202]	=	"Operador";
$TEXT[203]	=	"condición adicional :";
$TEXT[204]	=	"Y";
$TEXT[205]	=	"O";
$TEXT[206]	=	"Seleccionar";
$TEXT[207]	=	"Buscar";
$TEXT[208]	=	"Renombrar";
$TEXT[209]	=	"Mover";
$TEXT[210]	=	"Copiar";
$TEXT[211]	=	"Plugins";
$TEXT[212]	=	"Mantenimiento";
$TEXT[213]	=	"Tiempo de petición :";
$TEXT[214]	=	"mseg.";
$TEXT[215]	=	"Renombrar tabla a :";
$TEXT[216]	=	"Mover tabla a (database.table) :";
$TEXT[217]	=	"Copiar tabla a (database.table) :";
$TEXT[218]	=	"Añadir DROP TABLE";
$TEXT[219]	=	"Guardar como Nueva Fila";
$TEXT[220]	=	"Guardar";
$TEXT[221]	=	"Tipo de Guardar";
$TEXT[222]  =   "Operation";
$TEXT[223]  =   "Update";
$TEXT[224]  =   "Tip : You can use internal PHP functions in your queries !";
$TEXT[225]  =   "Truncated text";
$TEXT[226]  =   "Full text";
$TEXT[227]  =   "-- select --";
$TEXT[228]  =   "(s)";
$TEXT[229]  =   "Version";
$TEXT[230]  =   "(new database)";
$TEXT[231]  =   "Official SQliteManager Homepage";
$TEXT[232]  =   "The database can't be attain";
$TEXT[233]  =   "Trigger structure";
?>